from src.key_mwe.ngram_dict_tokeniser import NgramDictTokeniser
from src.key_mwe.workflow import StreamedPipeline


if __name__ == "__main__":  
    # import nltk
    # from nltk.corpus import stopwords
    # nltk.download('stopwords')
    # blacklist = set(stopwords.words("english"))
    blacklist: list[str] = ['have', 'by', 'while', 'how', 'own', 'me', 'no', 've', 'about', 'such', 'out', 'few', "wouldn't", 'further', 'these', 'when', 'his', 'your', 'you', 'will', 'o', 'were', 'needn', 'nor', 'can', 'above', 'below', "don't", 'd', 'an', 'any', 'then', 'not', 'this', 'himself', "should've", 'didn', "aren't", 'with', 'those', 'both', 'won', 'ours', "you'd", 'other', 'isn', 'doesn', 'ourselves', "hasn't", 'him', 'through', 'all', 'so', 'did', 'if', 'under', 'aren', 'down', 'i', "shouldn't", 'once', 'its', 'or', 'myself', 'on', 'just', 'been', 'are', 'most', 'as', 'who', "haven't", "needn't", "doesn't", 'wouldn', 'because', 'to', 'after', 'haven', 'same', 'she', 'having', 'against', 'll', 'more', 'wasn', 'their', 'herself', 'up', 'y', 'now', 'my', 'should', 'shouldn', 'couldn', 'itself', 'off', 'our', 'again', 'ma', 'her', 'of', 'which', 't', "couldn't", "didn't", 'why', 'hers', 'each', 'between', 'hadn', 'yourself', 'do', 'don', "isn't", "you've", 'am', 'than', 'yourselves', 'we', "weren't", 's', 'some', 'very', "hadn't", 'is', 'what', 'in', 'only', "won't", 'whom', 'yours', 'before', "she's", 'mustn', 'there', 'has', "you'll", 'where', 'until', 'hasn', 'that', "you're", 'being', 'mightn', "mightn't", 'shan', 'but', 'they', 'doing', 'the', 'be', 'at', 'he', "shan't", 'theirs', 'over', 'was', 'a', 'm', 'during', 'weren', "wasn't", 're', 'here', "that'll", 'does', 'too', 'ain', 'themselves', 'them', 'it', "mustn't", 'and', 'for', 'had', 'into', 'from', "it's"]

    
    # Workflow for extracting unigrams and collocations, from streamed corpus:
    mwe_range: list[int] = [2, 3, 4]
    content: str = "Compared to drugs and even food, cosmetics have been the regulatory stepchild in the Federal Food, Drug, and Cosmetic Act (FFDCA) since its adoption in 1938 - until now. At the end of 2022, Congress enacted legislation to mandate that cosmetic product manufacturers and processors take certain actions that the Food and Drug Administration (FDA) has encouraged them to take for years but for which it had no enforcement authority. Cosmetic producers beware: Increased regulation is coming by the end of 2023. Get ready now.\n\nThe Modernization of Cosmetics Regulation Act of 2022 (MoCRA) was tucked into the omnibus appropriations bill passed at the end of December. MoCRA appears as Subtitle E of Title II of Division H of the 1,653-page Consolidated Appropriations Act, 2023, Public Law 117-328 (Dec. 29, 2022), beginning at section 3501.\n\nThe passage of MoCRA as part of the omnibus illustrates how difficult it has been to enact legislation to strengthen FDA's authority over cosmetics. Since at least 2010, multiple Congresses have considered, but not enacted, cosmetic regulation bills. Legislation similar to MoCRA was introduced in 2017, 2019, and 2021. None passed, partly because of disputes between large and small cosmetic producers, and between the industry and NGOs.\n\nNow, however, Congress has enacted MoCRA, legislation that reflects numerous compromises. Most provisions take effect one year from enactment, or by December 29, 2023. The new labeling requirement becomes effective one year later on December 29, 2024. (MoCRA § 3503(b))\n\nMoCRA is mainly concerned with cosmetic products, a term defined to mean \"a preparation of cosmetic ingredients with a qualitatively and quantitatively set composition for use in a finished product.\" (FFDCA § 604(2)) In other words, a \"cosmetic product\" has been formulated but not necessarily packaged for retail sale. The term does not include chemicals intended for use in a cosmetic product. However, cosmetic ingredient suppliers can expect their customers to ask for help in compliance with some provisions.\n\nSome MoCRA provisions apply to cosmetic product facilities. \"Facility\" refers to an establishment that manufactures or processes cosmetic products distributed in the U.S., including foreign establishments. (FFDCA § 604(3))\n\nIn brief, MoCRA amends the FFDCA to add several new provisions:\n\nIn short, both FDA and cosmetic product manufacturers and processors have a lot of work to do. We understand that FDA is working on MoCRA implementation, but it has not yet commented on MoCRA on its website.\n\nAdverse event reporting (AER) is an early warning system for potential public health issues associated with using FDA-regulated products. It also serves as a mechanism to track patterns of adulteration in FDA-regulated products that supports FDA efforts to target limited inspection resources to protect public health. Until now, FDA's authority to require AER has been limited to prescription and non-prescription drugs, medical devices, biologics, dietary supplements, and food. With MoCRA, add cosmetics to that list.\n\nFDA has a voluntary AER system for cosmetics. MedWatch allows health care professionals and consumers to submit reports to FDA regarding problems with FDA-regulated products, including cosmetics. It also allows cosmetic user facilities, importers, and manufacturers to report using Form FDA 3500A.\n\nFFDCA § 605 only mandates reporting of a serious adverse event. That term is defined to mean an adverse event (i.e., any adverse health-related event associated with use of a cosmetic) that results in death, life-threatening experience, in-patient hospitalization, persistent or significant disability or incapacity, congenital anomaly or birth defect, an infection, serious disfigurement, or requires a medical or surgical intervention to prevent such an outcome. (FFDCA § 604(1), (5)) The reporting obligation would apply to any \"responsible party,\" including the manufacturer, packer, or distributor whose name appears on the cosmetic product's label. (FFDCA §§ 604(4), 605(a))\n\nCosmetic product manufacturers and distributors may want to familiarize themselves with the MedWatch system, as the new system may be similar.\n\nFDA has good manufacturing practice (GMP) regulations for other products it regulates. Without statutory authority to require GMPs for cosmetics, FDA has instead provided voluntary cosmetic product GMP guidance (2013, although still a draft).\n\nFFDCA § 606 directs FDA to adopt mandatory GMP regulations for cosmetic products, with simplified requirements for smaller businesses. The regulations are to be generally consistent with national and international standards. Since the FDA voluntary GMP guidance is brief, cosmetic product manufacturers, processors, and distributors may want to review ISO 22715:2006, Cosmetics - Packaging and labelling (last reviewed and confirmed in 2022). This international standard has provisions on personnel, premises, raw materials, packaging materials, production, finished products, quality control laboratory, dealing with out-of-specification results, complaints, recalls, change control, internal audits, and documentation.\n\nFDA must publish its proposed regulations by December 29, 2024, and its final regulations by December 29, 2025.\n\nFFDCA § 607(a) requires the owners and operators of existing cosmetic product facilities in the U.S. or that distribute to the U.S. to register with FDA by December 29, 2023. New facilities must be registered within 60 days of startup. Registrations will need to be renewed every two years, with changes to registration information to be reported within 60 days of the change. Registration will have significance since FDA can suspend a registration if it determines that the cosmetic products manufactured or processed at the facility may cause serious health consequences or death. A suspension would preclude the distribution of cosmetic products from that facility. (FFDCA § 607(f))\n\nSince 1974, FDA has promoted a Voluntary Cosmetic Registration Program. (21 C.F.R. Part 710) As the mandatory registration program is likely to be similar to the voluntary one, owners and operators of cosmetic product facilities in the U.S. or that distribute into the U.S. may want to review Part 710 and consider submitting Form FDA 2511 to register their facilities, if they have not already done so.\n\nFFDCA § 607(c) requires the responsible person for each cosmetic product currently marketed in the U.S. to list that product with FDA by December 29, 2023. New cosmetic products must be listed within 120 days of being marketed. Updated information must be submitted annually. Among other information, a product listing must include a list of ingredients, including fragrances, flavors, or colors, as provided in 21 C.F.R. § 701.3.\n\nFDA's Voluntary Cosmetic Registration Program includes voluntary product listing, referred to as voluntary filing of cosmetic product ingredient composition statements. (21 C.F.R. Part 720) As the mandatory product listing program is likely to be similar to the voluntary one, responsible persons may want to review Part 720 and consider submitting Form FDA 2512 for their cosmetic products if they have not already done so.\n\nFDA regulations currently require safety substantiation:\n\nEach ingredient used in a cosmetic product and each finished cosmetic product shall be adequately substantiated for safety prior to marketing. Any such ingredient or product whose safety is not adequately substantiated prior to marketing is misbranded unless it contains the following conspicuous statement on the principal display panel: \"Warning - The safety of this product has not been determined.\"\n\n21 C.F.R. § 740.10(a). FFDCA § 608 will bolster that requirement.\n\nIt requires the responsible person for a cosmetic product to ensure adequate substantiation of the product's safety, and to maintain records supporting that substantiation. \"Adequate substantiation of safety\" refers to tests, studies, research, or other information that is considered, among qualified experts, to be sufficient to support a reasonable certainty that a cosmetic product is safe. (FFDCA § 606(c)(1)) \"Safe\" means that the cosmetic product, including its ingredients, is not injurious to users under label conditions or customary or usual conditions. (FFDCA § 606(c)(2)) Cosmetic ingredient suppliers may expect requests from cosmetic product manufacturers for substantiation of the safety of their ingredients.\n\nThe FFDCA § 608 safety substantiation requirement takes effect on December 29, 2023. (MoCRA § 3503(b)(1)) Before that date, responsible persons should confirm that they have documentation to support that their cosmetic products have adequate substantiations of safety.\n\nFDA already has some labeling requirements for cosmetic products, 21 C.F.R. Part 701, and cosmetics labeling guidance. FFDCA § 609 supplements those requirements and that guidance. Labels meeting the new requirements are required for cosmetic products marketed on or after December 29, 2024. (MoCRA § 3503(b)(2))\n\nThe new label must:\n\nThe Factory Inspection authority of FFDCA § 704 extends to cosmetic product facilities. MoCRA § 3504 amended FFDCA § 704 to specify that inspections \"shall\" cover records and other information related to serious adverse event reporting, GMPs, and records covered by FFDCA § 610.\n\nFFDCA § 610 authorizes FDA to have access to all records related to cosmetic products and their ingredients which it reasonably believes may be adulterated to present a threat of serious adverse consequences or death.\n\nThis records access provision does not extend to recipes or formulas for cosmetics, financial data, pricing data, or personnel data (other than with respect to their qualifications), research data (other than safety substantiation data), or sales data (other than shipment data).\n\nWith FFDCA § 611, FDA now has recall authority for cosmetic products which it reasonably determines may be adulterated (including due to noncompliance with the new GMP or safety substantiation requirements) or misbranded (including due to noncompliance with the new labeling requirements). (MoCRA § 3503(a)(2), (3))\n\nThe provision lays out several procedural protections, including the requirement that FDA provide an opportunity for a voluntary recall.\n\nUnder FFDCA § 612, with some exceptions, small businesses (those with gross annual sales less than $1 million (adjusted for inflation)) are not subject to the GMP or facility registration and product listing requirements.\n\nUnder FFDCA § 613, cosmetic products that are also drugs are exempt from most MoCRA requirements. Facilities that manufacture or process cosmetic products subject to drug requirements are also exempt.\n\nMoCRA adds a new express preemption provision, FFDCA § 614(a). In general, no state or locality may impose any requirement for cosmetics regarding registration and product listing, GMPs, records, recalls, adverse event reporting, or safety substantiation that is not identical to the federal requirement.\n\nImportant exclusions from this preemption provision in FFDCA § 614(b) include state requirements:\n\nThis preemption provision does not affect the provision on preemption of requirements for labeling or packaging cosmetics in FFDCA § 752.\n\nSome cosmetics contain talc, and talc may potentially contain asbestos. FDA reports annual results from testing cosmetic products containing talc to see if they also contain asbestos.\n\nMoCRA § 3505 directs FDA to adopt regulations on standardized testing methods for detecting and identifying asbestos in talc-containing cosmetic products. The proposed rule is due by December 29, 2023. The final rule is due 180 days later.\n\nThe FDA website confirms that, \"PFAS are used as ingredients in certain cosmetics, such as lotions, cleansers, nail polish, shaving cream, and some types of makeup, such as lipstick, eyeliner, eyeshadow, and mascara.\"\n\nMoCRA § 3507 directs FDA to issue a report assessing the safety of using PFAS in cosmetic products. The report is due by December 29, 2025.\n\nAn FDA policy statement on animal testing says that \"animal testing by manufacturers seeking to market new products may be used to establish product safety\" after consideration of alternatives.\n\nMoCRA § 3507 conveys the sense of the Congress that:\n\nanimal testing should not be used for the purposes of safety testing on cosmetic products and should be phased out with the exception of appropriate allowances.\n\nThis provision does not bind FDA or manufacturers or processors of cosmetic products."
    sentences: list[str] = [sentence for sentence in content.split('\n') if sentence]
    tokeniser = NgramDictTokeniser(mwe_range, blacklist)   
    pipeline = StreamedPipeline()
    npmi_values: dict[int, list[tuple[str, float]]] = pipeline.extract_ngram_features(tokeniser, sentences)
    
    
    # Workflow for extracting key unigrams and collocations, from streamed corpus:
    mwe_range: list[int] = [2, 3, 4]
    content: str = "Compared to drugs and even food, cosmetics have been the regulatory stepchild in the Federal Food, Drug, and Cosmetic Act (FFDCA) since its adoption in 1938 - until now. At the end of 2022, Congress enacted legislation to mandate that cosmetic product manufacturers and processors take certain actions that the Food and Drug Administration (FDA) has encouraged them to take for years but for which it had no enforcement authority. Cosmetic producers beware: Increased regulation is coming by the end of 2023. Get ready now.\n\nThe Modernization of Cosmetics Regulation Act of 2022 (MoCRA) was tucked into the omnibus appropriations bill passed at the end of December. MoCRA appears as Subtitle E of Title II of Division H of the 1,653-page Consolidated Appropriations Act, 2023, Public Law 117-328 (Dec. 29, 2022), beginning at section 3501.\n\nThe passage of MoCRA as part of the omnibus illustrates how difficult it has been to enact legislation to strengthen FDA's authority over cosmetics. Since at least 2010, multiple Congresses have considered, but not enacted, cosmetic regulation bills. Legislation similar to MoCRA was introduced in 2017, 2019, and 2021. None passed, partly because of disputes between large and small cosmetic producers, and between the industry and NGOs.\n\nNow, however, Congress has enacted MoCRA, legislation that reflects numerous compromises. Most provisions take effect one year from enactment, or by December 29, 2023. The new labeling requirement becomes effective one year later on December 29, 2024. (MoCRA § 3503(b))\n\nMoCRA is mainly concerned with cosmetic products, a term defined to mean \"a preparation of cosmetic ingredients with a qualitatively and quantitatively set composition for use in a finished product.\" (FFDCA § 604(2)) In other words, a \"cosmetic product\" has been formulated but not necessarily packaged for retail sale. The term does not include chemicals intended for use in a cosmetic product. However, cosmetic ingredient suppliers can expect their customers to ask for help in compliance with some provisions.\n\nSome MoCRA provisions apply to cosmetic product facilities. \"Facility\" refers to an establishment that manufactures or processes cosmetic products distributed in the U.S., including foreign establishments. (FFDCA § 604(3))\n\nIn brief, MoCRA amends the FFDCA to add several new provisions:\n\nIn short, both FDA and cosmetic product manufacturers and processors have a lot of work to do. We understand that FDA is working on MoCRA implementation, but it has not yet commented on MoCRA on its website.\n\nAdverse event reporting (AER) is an early warning system for potential public health issues associated with using FDA-regulated products. It also serves as a mechanism to track patterns of adulteration in FDA-regulated products that supports FDA efforts to target limited inspection resources to protect public health. Until now, FDA's authority to require AER has been limited to prescription and non-prescription drugs, medical devices, biologics, dietary supplements, and food. With MoCRA, add cosmetics to that list.\n\nFDA has a voluntary AER system for cosmetics. MedWatch allows health care professionals and consumers to submit reports to FDA regarding problems with FDA-regulated products, including cosmetics. It also allows cosmetic user facilities, importers, and manufacturers to report using Form FDA 3500A.\n\nFFDCA § 605 only mandates reporting of a serious adverse event. That term is defined to mean an adverse event (i.e., any adverse health-related event associated with use of a cosmetic) that results in death, life-threatening experience, in-patient hospitalization, persistent or significant disability or incapacity, congenital anomaly or birth defect, an infection, serious disfigurement, or requires a medical or surgical intervention to prevent such an outcome. (FFDCA § 604(1), (5)) The reporting obligation would apply to any \"responsible party,\" including the manufacturer, packer, or distributor whose name appears on the cosmetic product's label. (FFDCA §§ 604(4), 605(a))\n\nCosmetic product manufacturers and distributors may want to familiarize themselves with the MedWatch system, as the new system may be similar.\n\nFDA has good manufacturing practice (GMP) regulations for other products it regulates. Without statutory authority to require GMPs for cosmetics, FDA has instead provided voluntary cosmetic product GMP guidance (2013, although still a draft).\n\nFFDCA § 606 directs FDA to adopt mandatory GMP regulations for cosmetic products, with simplified requirements for smaller businesses. The regulations are to be generally consistent with national and international standards. Since the FDA voluntary GMP guidance is brief, cosmetic product manufacturers, processors, and distributors may want to review ISO 22715:2006, Cosmetics - Packaging and labelling (last reviewed and confirmed in 2022). This international standard has provisions on personnel, premises, raw materials, packaging materials, production, finished products, quality control laboratory, dealing with out-of-specification results, complaints, recalls, change control, internal audits, and documentation.\n\nFDA must publish its proposed regulations by December 29, 2024, and its final regulations by December 29, 2025.\n\nFFDCA § 607(a) requires the owners and operators of existing cosmetic product facilities in the U.S. or that distribute to the U.S. to register with FDA by December 29, 2023. New facilities must be registered within 60 days of startup. Registrations will need to be renewed every two years, with changes to registration information to be reported within 60 days of the change. Registration will have significance since FDA can suspend a registration if it determines that the cosmetic products manufactured or processed at the facility may cause serious health consequences or death. A suspension would preclude the distribution of cosmetic products from that facility. (FFDCA § 607(f))\n\nSince 1974, FDA has promoted a Voluntary Cosmetic Registration Program. (21 C.F.R. Part 710) As the mandatory registration program is likely to be similar to the voluntary one, owners and operators of cosmetic product facilities in the U.S. or that distribute into the U.S. may want to review Part 710 and consider submitting Form FDA 2511 to register their facilities, if they have not already done so.\n\nFFDCA § 607(c) requires the responsible person for each cosmetic product currently marketed in the U.S. to list that product with FDA by December 29, 2023. New cosmetic products must be listed within 120 days of being marketed. Updated information must be submitted annually. Among other information, a product listing must include a list of ingredients, including fragrances, flavors, or colors, as provided in 21 C.F.R. § 701.3.\n\nFDA's Voluntary Cosmetic Registration Program includes voluntary product listing, referred to as voluntary filing of cosmetic product ingredient composition statements. (21 C.F.R. Part 720) As the mandatory product listing program is likely to be similar to the voluntary one, responsible persons may want to review Part 720 and consider submitting Form FDA 2512 for their cosmetic products if they have not already done so.\n\nFDA regulations currently require safety substantiation:\n\nEach ingredient used in a cosmetic product and each finished cosmetic product shall be adequately substantiated for safety prior to marketing. Any such ingredient or product whose safety is not adequately substantiated prior to marketing is misbranded unless it contains the following conspicuous statement on the principal display panel: \"Warning - The safety of this product has not been determined.\"\n\n21 C.F.R. § 740.10(a). FFDCA § 608 will bolster that requirement.\n\nIt requires the responsible person for a cosmetic product to ensure adequate substantiation of the product's safety, and to maintain records supporting that substantiation. \"Adequate substantiation of safety\" refers to tests, studies, research, or other information that is considered, among qualified experts, to be sufficient to support a reasonable certainty that a cosmetic product is safe. (FFDCA § 606(c)(1)) \"Safe\" means that the cosmetic product, including its ingredients, is not injurious to users under label conditions or customary or usual conditions. (FFDCA § 606(c)(2)) Cosmetic ingredient suppliers may expect requests from cosmetic product manufacturers for substantiation of the safety of their ingredients.\n\nThe FFDCA § 608 safety substantiation requirement takes effect on December 29, 2023. (MoCRA § 3503(b)(1)) Before that date, responsible persons should confirm that they have documentation to support that their cosmetic products have adequate substantiations of safety.\n\nFDA already has some labeling requirements for cosmetic products, 21 C.F.R. Part 701, and cosmetics labeling guidance. FFDCA § 609 supplements those requirements and that guidance. Labels meeting the new requirements are required for cosmetic products marketed on or after December 29, 2024. (MoCRA § 3503(b)(2))\n\nThe new label must:\n\nThe Factory Inspection authority of FFDCA § 704 extends to cosmetic product facilities. MoCRA § 3504 amended FFDCA § 704 to specify that inspections \"shall\" cover records and other information related to serious adverse event reporting, GMPs, and records covered by FFDCA § 610.\n\nFFDCA § 610 authorizes FDA to have access to all records related to cosmetic products and their ingredients which it reasonably believes may be adulterated to present a threat of serious adverse consequences or death.\n\nThis records access provision does not extend to recipes or formulas for cosmetics, financial data, pricing data, or personnel data (other than with respect to their qualifications), research data (other than safety substantiation data), or sales data (other than shipment data).\n\nWith FFDCA § 611, FDA now has recall authority for cosmetic products which it reasonably determines may be adulterated (including due to noncompliance with the new GMP or safety substantiation requirements) or misbranded (including due to noncompliance with the new labeling requirements). (MoCRA § 3503(a)(2), (3))\n\nThe provision lays out several procedural protections, including the requirement that FDA provide an opportunity for a voluntary recall.\n\nUnder FFDCA § 612, with some exceptions, small businesses (those with gross annual sales less than $1 million (adjusted for inflation)) are not subject to the GMP or facility registration and product listing requirements.\n\nUnder FFDCA § 613, cosmetic products that are also drugs are exempt from most MoCRA requirements. Facilities that manufacture or process cosmetic products subject to drug requirements are also exempt.\n\nMoCRA adds a new express preemption provision, FFDCA § 614(a). In general, no state or locality may impose any requirement for cosmetics regarding registration and product listing, GMPs, records, recalls, adverse event reporting, or safety substantiation that is not identical to the federal requirement.\n\nImportant exclusions from this preemption provision in FFDCA § 614(b) include state requirements:\n\nThis preemption provision does not affect the provision on preemption of requirements for labeling or packaging cosmetics in FFDCA § 752.\n\nSome cosmetics contain talc, and talc may potentially contain asbestos. FDA reports annual results from testing cosmetic products containing talc to see if they also contain asbestos.\n\nMoCRA § 3505 directs FDA to adopt regulations on standardized testing methods for detecting and identifying asbestos in talc-containing cosmetic products. The proposed rule is due by December 29, 2023. The final rule is due 180 days later.\n\nThe FDA website confirms that, \"PFAS are used as ingredients in certain cosmetics, such as lotions, cleansers, nail polish, shaving cream, and some types of makeup, such as lipstick, eyeliner, eyeshadow, and mascara.\"\n\nMoCRA § 3507 directs FDA to issue a report assessing the safety of using PFAS in cosmetic products. The report is due by December 29, 2025.\n\nAn FDA policy statement on animal testing says that \"animal testing by manufacturers seeking to market new products may be used to establish product safety\" after consideration of alternatives.\n\nMoCRA § 3507 conveys the sense of the Congress that:\n\nanimal testing should not be used for the purposes of safety testing on cosmetic products and should be phased out with the exception of appropriate allowances.\n\nThis provision does not bind FDA or manufacturers or processors of cosmetic products."
    sentences_positive: list[str] = [sentence for sentence in content.split('\n') if sentence]
    content_reference: list[str] = [
        "Advertiser content Shaping the future of sustainable, healthy and nutritious food CHAP (Crop Health & Protection) 15 February 2024 >More in Agricultural transition Provided by\n\nCHAP is one of the four UK Agri-Tech Centres of Innovation. We bring together scientists, farmers, advisors, and pioneers to advance crop productivity and yield in the UK and beyond.\n\n© Chap\n\nSustainable food is becoming increasingly popular among health-conscious consumers, not just for its environmental benefits but also for the perception that it is more nutritious than non-sustainable alternatives.\n\nBut does sustainable food truly hold a nutritional edge over its conventional counterparts?\n\nSustainability in agri-tech centres around meeting demand for food whilst maintaining the productivity and health of the land over time, ensuring economic viability, and fostering social equity.\n\nWhen we link sustainability to nutrition, we're looking at how these practices contribute to producing food that not only feeds the population but does so in a way that is nutrient-rich and beneficial to our health.\n\n© Chap\n\nSustainable farming techniques\n\nSustainable agriculture focuses on practices designed to maintain the productivity and health of the land over time.\n\nTechniques such as crop rotation, cover cropping, and reduced tillage not only conserve soil health but also influence the nutritional content of food. These practices, by promoting biodiversity and soil fertility, can lead to crops that are potentially richer in nutrients.\n\nCrop Health and Protection (CHAP- one of the three Agri-Tech Centres) is committed to sustainable practices that enhance food nutritional quality while minimising environmental impact, and advocates for advances in integrated pest management as well as precision agriculture with projects like SprayBot and SLIMERS.\n\nThe role of plant-based proteins\n\nPlant-based diets are not only associated with lower environmental impact but also with improved health outcomes and lower environmental footprints.\n\nFoods like legumes, nuts, and whole grains are staples of a plant-based diet and are rich sources of fibre, vitamins, and minerals.\n\nBy supporting the production of sustainable plant-based proteins, projects including Sustainable Lupins and Sustainable Legumes are contributing to a food system that supports both the planet's health and our own.\n\nAchieving sustainable plant-based proteins within the UK's production systems is a key part of CHAP's portfolio of work, highlighting the important role of innovation and collaborative R&D in advancing the alternative protein sector for improved sustainability and productivity.\n\n© Chap\n\nNutrient circularity in agriculture\n\nAnother area of interest which the Agri-Tech Centres have been exploring as part of their New Innovations programme is nutrient circularity.\n\nTaking a controlled environment agriculture (CEA) and total controlled environment agriculture (TCEA) approach, there is potential for agricultural practices to produce crops with enhanced nutritional profiles in an environmentally conscious way and can lead to enhanced nutrient profiles in the food produced.\n\nAeroponics increase a plants access to oxygen and nutrients, and CHAP's collaboration with LettUs Grow on the Advanced Aeroponics project demonstrates how we can integrate tech into improving farming practices both in theory and on a commercial level.\n\nThe soil microbiome's impact on nutrition\n\nThe health of the soil microbiome is crucial for sustainable agriculture and can have an impact on the nutritional quality of crops. A diverse and healthy soil microbiome can improve plant growth, increase nutrient uptake, and enhance the nutritional content of crops.\n\nResearch into the soil microbiome and its role in sustainable agriculture underscores the importance of maintaining soil health for the production of nutritious food\n\nJoin the conversation\n\nInnovation Sector Lead and alternative protein specialist Dr Réka Haraszi will be discussing the need for a varied sources of protein in the food supply chain, under-utilised crops and inviting delegates from across the sector to join the conversation at the Plant Protein Connect event in Sheffield on 12 March 2024.\n\nThe event will focus on eliminating the barriers of collaboration within the plant-based protein sector in the UK.\n\nSee more Agricultural transition",
        "STUTTGART, Germany--(BUSINESS WIRE)--Feb 22, 2024--\n\nMercedes-Benz Group AG (ticker symbol: MBG) achieved solid 2023 financial results. A sharpened focus on desirable cars and vans combined with ongoing cost discipline resulted in Group Earnings Before Interest and Taxes (EBIT) of €19.7 billion (2022: €20.5 billion), and revenues of €153.2 billion (2022: €150.0 billion). For 2023, Mercedes-Benz Cars delivered an adjusted Return on Sales (RoS) of 12.6%, Mercedes-Benz Vans an adjusted RoS of 15.1%, and Mercedes-Benz Mobility an adjusted Return on Equity (RoE) of 12.3%, in a challenging environment marked by supply-chain constraints as well as geopolitical and macroeconomic volatility.\n\n\"Mercedes-Benz continued its transformation in 2023, developing new cutting-edge electric and digital innovations, while scaling electric vehicles and delivering solid financial results. In other words, the team once again came through to execute our strategy in challenging times, delivering the eSprinter and the new E-Class. At the same time, we prepared the ground for next-generation products and platforms like VAN.EA and MB.OS. to keep Mercedes-Benz at the forefront of the industry.\"\n\nOla Kaellenius, Chief Executive Officer of Mercedes-Benz Group AG.\n\n*The figures in this document are preliminary and have neither been approved yet by the Supervisory Board nor audited by the external auditor.\n\nMercedes-Benz Group\n\nQ4 2023\n\nQ4 2022\n\nChange\n\n23/22\n\nFY\n\n2023\n\nFY\n\n2022\n\nChange\n\n23/22\n\nRevenue*\n\n40,261\n\n41,003\n\n-1.8%\n\n153,218\n\n150,017\n\n+2.1%\n\nEarnings before Interest and Taxes (EBIT)*\n\n4,326\n\n5,411\n\n-20.1%\n\n19,660\n\n20,458\n\n-3.9%\n\nEarnings before Interest and Taxes (EBIT) adjusted*\n\n4,456\n\n5,071\n\n-12.1%\n\n20,004\n\n20,655\n\n-3.2%\n\nNet profit/loss*\n\n3,160\n\n4,027\n\n-21.5%\n\n14,531\n\n14,809\n\n-1.9%\n\nFree Cash Flow (industrial business) *\n\n3,442\n\n2,479\n\n+38.8%\n\n11,316\n\n8,128\n\n+39.2%\n\nEarnings per share (EPS) in EUR\n\n2.99\n\n3.72\n\n-19.7%\n\n13.46\n\n13.55\n\n-0.7%\n\n*in millions of €\n\nInvestments, Free Cash Flow and Net Liquidity\n\nThe Free Cash Flow of the Industrial Business reached €11.3 billion (2022: €8.1 billion) mainly due to high profitability, a high cash conversion rate and lower working capital. The Net Liquidity of the Industrial Business rose to €31.7 billion (end of 2022: €26.6 billion). Group investments in property, plant and equipment in the full year totaled €3.7 billion (2022: €3.5 billion). Research & Development expenditure amounted to €10.0 billion (2022: €8.5 billion).\n\nTransformation\n\nMercedes-Benz gained certification for its SAE Level 3 conditionally automated driving system for use on freeways in Nevada and California and received permission to test its L3 systems on highways in Beijing. These innovations come ahead of the introduction of its operating system MB.OS which will be launched with the new Mercedes-Benz Modular Architecture (MMA) which sets new efficiency benchmarks. Mercedes-Benz started its rollout of a dedicated high-power charging network, with sites opening in China, the U.S. and Germany. The company also continued expanding its direct sales model including most recently in Thailand. Direct sales is now live in 11 markets and covers more than 50% of sales in Europe and more than 30% in the Overseas region.\n\nDivisional results\n\nThe adjusted Earnings Before Interest and Taxes at Mercedes-Benz Cars reached €14.3 billion (2022: €16.2 billion) and the adjusted Return on Sales resulted in a solid 12.6% (2022: 14.6%). Hereby, tailwinds from net pricing, lower raw material prices and improved manufacturing costs were outweighed by higher inflation charges and supply-chain related costs.\n\nResearch and Development costs rose for future platforms and technologies, particularly for MB.OS. Net pricing increased significantly with the average sales price up 2% to €74,200 in 2023 and remained positive on a healthy level also in the fourth quarter.\n\nOverall sales volumes remained flat, reaching 2,044,100 units in 2023 and included a sales increase for Mercedes-Maybach (+19%), G-Class (+11%) and Mercedes-AMG (+4%). The model mix remained flat, but on a high level, with Top-End vehicle sales reaching 328,300 last year. The S-Class remains the undisputed leader in its segment, retaining its market share with around 50% in all key regions. Battery electric vehicles now account for 12% of overall Mercedes-Benz Cars sales with Mercedes-Benz reaching the highest share of EV's among all traditional foreign OEMs in the United States in 2023.\n\nThe adjusted Cash Flow Before Interest and Taxes (CFBIT) of Mercedes-Benz Cars increased by 10% to €12.5 billion in 2023 (2022: €11.4 billion) due to improved working capital, resulting in a favorable adjusted Cash Conversion Rate of 0.9 compared to 0.7 last year.\n\nMercedes-Benz Cars (including smart)\n\nQ4 2023\n\nQ4 2022\n\nChange\n\n23/22\n\nFY\n\n2023\n\nFY\n\n2022\n\nChange\n\n23/22\n\nSales in units\n\n514,258\n\n536,181\n\n-4.1%\n\n2,044,051\n\n2,040,719\n\n+0.2%\n\n- thereof xEV\n\n112,043\n\n111,046\n\n+0.9%\n\n401,943\n\n333,490\n\n+20.5%\n\n- thereof BEV\n\n66,197\n\n53,539\n\n+23.6%\n\n240,668\n\n149,227\n\n+61.3%\n\nRevenue*\n\n29,569\n\n30,557\n\n-3.2%\n\n112,756\n\n111,601\n\n+1.0%\n\nEarnings Before Interest and Taxes (EBIT)*\n\n2,912\n\n4,243\n\n-31.4%\n\n14,224\n\n16,340\n\n-12.9%\n\nEarnings Before Interest and Taxes (EBIT) adjusted*\n\n2,970\n\n4,088\n\n-27.3%\n\n14,252\n\n16,245\n\n-12.3%\n\nReturn on Sales (RoS) in %\n\n9.8\n\n13.9\n\n-4.1%pts\n\n12.6\n\n14.6\n\n-2.0%pts\n\nReturn on Sales (RoS) adjusted in %\n\n10.0\n\n13.4\n\n-3.4%pts\n\n12.6\n\n14.6\n\n-2.0%pts\n\nCash Flow Before Interest and Taxes (CFBIT)*\n\n3,438\n\n3,104\n\n+10.8%\n\n12,336\n\n10,718\n\n+15.1%\n\nCash Flow Before Interest and Taxes (CFBIT) adjusted*\n\n3,478\n\n3,233\n\n+7.6%\n\n12,535\n\n11,413\n\n+9.8%\n\nCash Conversion Rate adjusted\n\n1.2\n\n0.8\n\n-\n\n0.9\n\n0.7\n\n-\n\n*in millions of €\n\nRevenue at Mercedes-Benz Vans rose by 18% to €20.3 billion (2022: €17.2 billion) and adjusted EBIT increased 59% to €3.1 billion (2022: €1.9 billion) year-on-year, as unit sales improved 8% to a record 447,800 units (2022: 415,300 units).\n\nThe strong financial performance is a result of strong product substance, a healthy price premium and product mix, robust net pricing and lower raw material costs. These factors, combined with efficiency measures, helped to offset higher inflation-related and logistic costs. In line with the value growth strategy to focus on premium segments, large Vans dominated sales, resulting in record sales in the U.S., the Sprinter leading its segment in Europe and Mercedes-Benz Vans leading the market in Germany. With 237,400 large, 178,900 mid-size and 31,500 small vans sold, Mercedes-Benz Vans achieved its best annual result to date in each segment.\n\nIn the United States, sales grew by 13% to an annual record of 75,100 units. With around 22,700 eVans, sales of electric vans increased by 51% in 2023, accounting for 5% of total sales. Last year also saw the premiere of the new eSprinter and the facelift of the mid-size van portfolio. With the eCitan, EQT (WLTP: combined electricity consumption 100 kWh/km: 20,7-19,3; combined CO2 emissions: 0 g/km), eVito, eVito Tourer, EQV and eSprinter, Mercedes-Benz Vans offers each model also as an all-electric version since 2023. Research and development costs increased due to an investment focus on Van Electric Architecture (VAN.EA). Investments into property, plants and equipment rose as plants were retooled to build the new eSprinter and the facelift of the mid-size vans and to build the all-new generation of electric vans. Full year the adjusted cash flow surged by 48% to €3.0 billion (2022: €2.0 billion), resulting in a strong adjusted Cash Conversation Rate of 1.0 (2022: 1.1).\n\nMercedes-Benz Vans\n\nQ4 2023\n\nQ4 2022\n\nChange\n\n23/22\n\nFY\n\n2023\n\nFY\n\n2022\n\nChange\n\n23/22\n\nSales in units\n\n124,317\n\n122,733\n\n+1.3%\n\n447,790\n\n415,344\n\n+7.8%\n\nRevenue*\n\n5,611\n\n5,114\n\n+9.7%\n\n20,288\n\n17,217\n\n+17.8%\n\nEarnings before Interest and Taxes (EBIT)*\n\n855\n\n670\n\n+27.6%\n\n3,138\n\n1,897\n\n+65.4%\n\nEarnings before Interest and Taxes (EBIT) adjusted*\n\n809\n\n501\n\n+61.5%\n\n3,063\n\n1,927\n\n+59.0%\n\nReturn on Sales (RoS) in %\n\n15.2\n\n13.1\n\n+2.1%pts\n\n15.5\n\n11.0\n\n+4.5%pts\n\nReturn on Sales (RoS) adjusted in %\n\n14.4\n\n9.8\n\n+4.6%pts\n\n15.1\n\n11.2\n\n+3.9%pts\n\nCash Flow Before Interest and Taxes (CFBIT)*\n\n650\n\n665\n\n-2.3%\n\n2,817\n\n1,731\n\n+62.7%\n\nCash Flow Before Interest and Taxes (CFBIT) adjusted*\n\n714\n\n741\n\n-3.6%\n\n3,018\n\n2,040\n\n+47.9%\n\nCash Conversion Rate adjusted\n\n0.9\n\n1.5\n\n-\n\n1.0\n\n1.1\n\n-\n\n*in millions of €\n\nMercedes-Benz Mobility saw new business increase by 7% to €62.0 billion (2022: €58.0 billion) in a competitive market environment with above average penetration rates for financed or leased electric vehicles. The total portfolio grew in 2023 to €135.0 billion (2022: €132.4 billion). Performance was impacted by a lower portfolio margin due to higher refinancing rates and intensified competition in the financial services sector, resulting in adjusted Earnings Before Interest and Taxes of €1.7 billion (2022: €2.4 billion). The expenses for the establishment of charging activities also had an effect on EBIT. The charging business continued its global ramp up with high-power charging stations opening in Germany, the U.S. and China. As a result, the adjusted Return on Equity (RoE) was at 12.3% (2022: 16.8%).\n\nMercedes-Benz Mobility\n\nQ4 2023\n\nQ4 2022\n\nChange\n\n23/22\n\nFY\n\n2023\n\nFY\n\n2022\n\nChange\n\n23/22\n\nRevenue*\n\n7,012\n\n6,858\n\n+2.2%\n\n26,718\n\n26,954\n\n-0.9%\n\nNew business*\n\n16,715\n\n15,121\n\n+10.5%\n\n62,014\n\n58,031\n\n+6.9%\n\nContract volume (December, 31)*\n\n135,027\n\n132,379\n\n+2.0%\n\n135,027\n\n132,379**\n\n+2.0%\n\nEarnings before Interest and Taxes (EBIT)*\n\n228\n\n494\n\n-53.8%\n\n1,302\n\n2,428\n\n-46.4%\n\nEarnings before Interest and Taxes (EBIT) adjusted*\n\n345\n\n494\n\n-30.2%\n\n1,695\n\n2,428\n\n-30.2%\n\nReturn on Equity (RoE) in %\n\n6.8\n\n14.0\n\n-7.2%pts\n\n9.5\n\n16.8\n\n-7.3%pts\n\nReturn on Equity (RoE) adjusted in %\n\n10.3\n\n14.0\n\n-3.7%pts\n\n12.3\n\n16.8\n\n-4.5%pts\n\n*in millions of €\n\n** Year-end figure 2022\n\nDividend\n\nAt the Annual General Meeting on May 8, 2024, the Board of Management and the Supervisory Board will propose a dividend of €5.30 per share (2022: €5.20). This proposal also reflects the Earnings per Share (EPS) accretion effect of the current share buyback program.\n\nShare buyback policy\n\nMercedes-Benz has resolved to implement a new buyback policy. Any future free cash flow from the industrial business as available (post potential small-scale M&A) beyond the approx. 40 percent dividend payout ratio of Group Net Income, shall be used to fund share buybacks with the purpose of redeeming shares.\n\nIn this context, Mercedes-Benz has also announced an additional share buyback program to repurchase own shares worth up to €3 billion (not including incidental costs) on the stock exchange. The repurchased shares shall subsequently be cancelled.\n\nThe buyback will be based on the authorization by the Annual General Meeting of Mercedes-Benz Group AG on July 8, 2020, allowing the Board of Management to acquire, with the approval of the Supervisory Board, own shares up to a maximum of ten percent of the share capital until July 7, 2025. The buyback will commence immediately after the conclusion of the ongoing share buyback program announced on February 16, 2023, and is expected to be completed before the expiry of the Annual General Meeting's current authorization.\n\nThe company intends to ask for a renewal of the authorization for Share Buybacks at the Annual General Meeting in 2025 to further continue Share Buybacks in line with the company's Share Buyback policy. This Share Buyback policy targets continuous growth of Earnings Per Share (EPS) and Dividend Per Share (DPS) over the next years. With any Share Buyback Program the company will keep flexibility on the execution in case of unexpected market developments.\n\nOutlook\n\nThe economic situation and automotive markets continue to be characterized by an exceptional degree of uncertainty. Unexpected developments may arise in particular from geopolitical events and trade policy. Among them are the current Middle East conflict, the Russia-Ukraine war and other regional crises. Other potential uncertainties include the exacerbation of tensions between China the United States and a further deterioration of political relations between the European Union and China. Further supply chain disruptions and in particular, availability bottlenecks for critical components, remain a significant risk factor. These may impact supply chains and the development of prices for raw materials and energy. In addition, higher-than-expected inflation and interest rates, potential financial market disruptions and an even more pronounced slowdown in economic growth, may have an impact on the world economy and automotive markets.\n\nFrom 2024 onwards, Mercedes-Benz will introduce a new guidance KPI: An xEV share for sales of new Cars and Vans. This will replace the current CO 2 emissions KPI for the new car fleet in Europe and reflects the global activities of the Mercedes-Benz Group.\n\nSales guidance: The company sees unit sales of Mercedes-Benz Cars at the prior-year level, even as current supply bottlenecks are easing. However, some topics remain and will impact sales in 2024. This will last probably throughout the first half of 2024 and in particular affect sales in the first quarter, which is expected below prior-year level.\n\nThe xEV share is expected to remain at approximately 19% - 21% of new car sales.\n\nThe adjusted Return on Sales (RoS) is expected in the range of a solid 10% - 12% in a demanding environment on flat volumes and a continued high share of Top-End Vehicle sales. Mercedes-Benz Cars will seek to defend and hold pricing at 2023 levels. The used vehicle business is expected to be on a healthy positive level in absolute terms, however, slightly below 2023. The company expects smaller headwinds on foreign exchange rates and Research & Development spending is expected to be flat. Investments in property plant & equipment are seen significantly higher, mainly due to the MMA platform. Some material tailwinds on raw material costs are seen and further headwinds on supply-chain related costs are expected. Overall, on material costs, a slight tailwind is expected in 2024. The mid-term target to reduce investments (R&D and PP&E) by 20% versus 2019 levels is expected to be met in the second half of the decade due to an accelerated BEV product plan with MB.EA.\n\nThe adjusted cash conversion rate (CCR) corridor for Mercedes-Benz Cars remains at 0.8 to 1.0.\n\nTotal Mercedes-Benz Vans sales are expected to soften in H2 2024 and be slightly lower in 2024 with a strong first quarter. The xEV share is expected between 6% to 8% with the new eSprinter available for sale in the beginning of 2024.\n\nInvestment in property, plants & equipment and research & development spending are seen significantly above the prior-year level due to investments into the purpose-built electric architecture called VAN.EA.\n\nThe adjusted RoS is seen in the range of 12% - 14%. Net pricing and mix are expected to develop solidly and the adjusted CCR for Mercedes-Benz Vans is seen at 0.6 to 0.8.\n\nThe portfolio volume of Mercedes-Benz Mobility is seen on the same level as 2023 with slightly positive new business development. The adjusted Return on Equity is seen in the range of 10% - 12%. The interest margin remains under pressure in the first half of 2024. The deteriorating acquisition margin has started to improve, although it takes time for this to feed through to the portfolio. For Q1 Mercedes-Benz Mobility expects a margin below the full year guidance corridor.\n\nThe Mercedes-Benz Group expects Group revenue in 2024 to remain at the prior-year level. In a market environment that remains challenging, Group EBIT is expected to be slightly below the previous year's level resulting out of divisional guidances. Group Free Cash Flow of the Industrial Business is seen slightly below the very strong levels from 2023, due to lower EBIT at Cars and Vans and lower CCR at Vans.\n\nStrategic priorities\n\nMercedes-Benz will continue to focus on its brand promise: to build the world's most desirable cars. Mercedes-Benz will remain strategically focused and tactically flexible and is taking the necessary steps to go all electric. Customers and market conditions will set the pace of the transformation. The company plans to be in a position to cater to different customer needs, whether it's an all-electric drivetrain or an electrified combustion engine, until well into the 2030s.\n\nThe company expects xEV sales to reach up to 50% of overall sales in the second half of the decade. Factories are retooled to follow demand to capture the tipping point into an all-electric era. Mercedes-Benz has set the course with the development of several new vehicle platforms. The starting point will be next year with the all-new electric CLA. While the upcoming models will set standards in improving efficiency and charging time, the company believes that the battery costs per kilowatt hour can be reduced by more than 30% in the next few years, thanks to optimized cell and module design, improved vehicle integration, further development of cell chemistries (e.g. NMC, next generation LFP), cell updates during the lifecycle and continuous improvement agreements with suppliers.\n\nOn the digital side, the company-owned operating system MB.OS is expected to mark an important milestone in the field of car software. Moreover, Mercedes-Benz will continue to pioneer advancements in automated driving. Mercedes-Benz will continue to optimize its industrial footprint and cost base, for example by working on structurally lower material costs in close collaboration with its suppliers.\n\nBy implementing this strategy, Mercedes-Benz expects to deliver on the essence of the brand: a unique combination of iconic luxury and leading technology.\n\nLink to press release \"Sales figures 2023\": group-media.mercedes-benz.com/annual sales\n\nLink to capital market presentation on full year 2023: group.mercedes-benz.com/results-2023\n\nPictures of the Annual Results Conference 2023 will be available here: group-media.mercedes-benz.com\n\nFurther information on Mercedes-Benz Group AG is available at:\n\ngroup-media.mercedes-benz.com and group.mercedes-benz.com\n\nForward-looking statements:\n\nThis document contains forward-looking statements that reflect our current views about future events. The words \"anticipate\", \"assume\", \"believe\", \"estimate\", \"expect\", \"intend\", \"may\", \"can\", \"could\", \"plan\", \"project\", \"should\" and similar expressions are used to identify forward-looking statements. These statements are subject to many risks and uncertainties, including an adverse development of global economic conditions, in particular a negative change in market conditions in our most important markets; a deterioration of our refinancing possibilities on the credit and financial markets; events of force majeure including natural disasters, pandemics, acts of terrorism, political unrest, armed conflicts, industrial accidents and their effects on our sales, purchasing, production or financial services activities; changes in currency exchange rates, customs and foreign trade provisions; changes in laws, regulations and government policies (or changes in their interpretation), particularly those relating to vehicle emissions, fuel economy and safety or to ESG reporting (environmental, social or governance topics); price increases for fuel, raw materials or energy; disruption of production due to shortages of materials or energy, labor strikes or supplier insolvencies; a shift in consumer preferences towards smaller, lower-margin vehicles; a limited demand for all-electric vehicles; a possible lack of acceptance of our products or services which limits our ability to achieve prices and adequately utilize our production capacities; a decline in resale prices of used vehicles; the effective implementation of cost-reduction and efficiency-optimization measures; the business outlook for companies in which we hold a significant equity interest; the successful implementation of strategic cooperations and joint ventures; the resolution of pending governmental investigations or of investigations requested by governments and the outcome of pending or threatened future legal proceedings; and other risks and uncertainties, some of which are described under the heading \"Risk and Opportunity Report\" in the current Annual Report. If any of these risks and uncertainties materializes or if the assumptions underlying any of our forward-looking statements prove to be incorrect, the actual results may be materially different from those we express or imply by such statements. We do not intend or assume any obligation to update these forward-looking statements since they are based solely on the circumstances at the date of publication.\n\nMercedes-Benz Group at a glance\n\nMercedes-Benz Group AG is one of the world's most successful automotive companies. With Mercedes-Benz AG, the Group is one of the leading global suppliers of high-end passenger cars and premium vans. Mercedes-Benz Mobility AG offers financing, leasing, car subscription and car rental, fleet management, digital services for charging and payment, insurance brokerage, as well as innovative mobility services. The company founders, Gottlieb Daimler and Carl Benz, made history by inventing the automobile in 1886. As a pioneer of automotive engineering, Mercedes-Benz sees shaping the future of mobility in a safe and sustainable way as both a motivation and obligation. The company's focus therefore remains on innovative and green technologies as well as on safe and superior vehicles that both captivate and inspire. Mercedes-Benz continues to invest systematically in the development of efficient powertrains and sets the course for an all-electric future. Mercedes-Benz is consistently implementing its strategy to transform itself toward a fully electric and software-driven future. The company's efforts are also focused on the intelligent connectivity of its vehicles, autonomous driving and new mobility concepts as Mercedes-Benz regards it as its aspiration and obligation to live up to its responsibility to society and the environment. Mercedes-Benz sells its vehicles and services in nearly every country of the world and has production facilities in Europe, North and Latin America, Asia and Africa. In addition to Mercedes-Benz, the world's most valuable luxury automotive brand (source: Interbrand study, 22 Nov. 2023), Mercedes-AMG, Mercedes-Maybach and Mercedes me as well as the brands of Mercedes-Benz Mobility: Mercedes-Benz Bank, Mercedes-Benz Financial Services and Athlon. The company is listed on the Frankfurt and Stuttgart stock exchanges (ticker symbol MBG). In 2023, the Group had a workforce of around 166,000 and sold around 2.5 million vehicles. Group revenues amounted to €153.2 billion and Group EBIT to €19.7 billion.\n\nView source version on businesswire.com:https://www.businesswire.com/news/home/20240221094253/en/\n\nCONTACT: Willem Spelten, +49 151 58624395,willem.spelten@mercedes-benz.com\n\nEdward Taylor, +49 176 30 94 1776,edward.taylor@mercedes-benz.com\n\nBenjamin Kraft, +49 176 3095 7277,benjamin.b.kraft@mercedes-benz.com\n\nAndrea Berg, +1 917 667 2391,andrea.a.berg@mercedes-benz.com\n\nKEYWORD: GERMANY EUROPE UNITED STATES NORTH AMERICA\n\nINDUSTRY KEYWORD: ALTERNATIVE VEHICLES/FUELS EV/ELECTRIC VEHICLES VEHICLE TECHNOLOGY AUTOMOTIVE GENERAL AUTOMOTIVE AUTOMOTIVE MANUFACTURING MANUFACTURING RECREATIONAL VEHICLES PERFORMANCE & SPECIAL INTEREST OFF-ROAD TRUCKS & SUVS\n\nSOURCE: Mercedes-Benz Group AG\n\nCopyright Business Wire 2024.\n\nPUB: 02/22/2024 01:43 AM/DISC: 02/22/2024 01:43 AM\n\nhttp://www.businesswire.com/news/home/20240221094253/en",
        "February 20, 2024 -- Jacksonville, Fla. -- WJCT Public Media and the Jacksonville Symphony are partnering to bring the Symphony's classical performances to a wider audience. In an exciting collaboration, recordings of the Jacksonville Symphony's classical concerts will now be included in the schedule of Classical 24, one of WJCT's HD radio stations that is accessible through national streaming services. The first broadcast will air at 7 p.m. Sunday, March 3, 2024.\n\nThis partnership marks a significant milestone for both organizations, showcasing their commitment to enriching the cultural landscape of the region and sharing it with a broader audience.\n\n\"This partnership between the Jacksonville Symphony and WJCT Public Media represents a fusion of artistic excellence and community outreach,\" said Steven Libman, President and CEO of the Jacksonville Symphony. \"We are thrilled to bring the magic of live, orchestral performances to a wider audience, allowing more people to experience the transformative power of classical music.\"\n\nThe inaugural series will feature eight concerts from the Symphony's 2022/2023 season, kicking off with Tchaikovsky's Piano Concerto No. 1. Each performance will be accompanied by insightful commentary from the Jacksonville Symphony's Music Director, Courtney Lewis, providing listeners with a deeper understanding and appreciation of the music.\n\n\"We are delighted to work with the Jacksonville Symphony to enable audiences to experience their local orchestra outside of the symphony hall, and to allow listeners outside of Northeast Florida to hear their quality,\" said David McGowan, President and CEO of WJCT Public Media. \"All of our Jacksonville Music Experience (JME) services, including Classical 24, aim to share the magic of music performance in our region, so this partnership is exciting for all of us.\"\n\nThrough this collaboration, the Jacksonville Symphony and WJCT Public Media aim to inspire, educate and entertain audiences while fostering a deeper connection to the arts. By leveraging their combined resources and expertise, these two leading nonprofit organizations are poised to make a meaningful impact on the cultural landscape of the region.\n\nThe inaugural series includes encore performances of the following Jacksonville Symphony performances from the 2022/23 season:\n\nWJCT Public Media's Classical 24 station can be found enjoyed on 89.9 HD 2, at wjct.org/jaxmusic/classical24/ or by asking a smart speaker to play Classical 24.\n\nFor more information and to view the broadcast schedule, visit the Jacksonville Symphony's website at jaxsymphony.org and WJCT's website at wjct.org.\n\nThe Jacksonville Symphony is North Florida's leading performing arts organization offering live performances at Jacoby Symphony Hall in the Jacksonville Center for the Performing Arts and other venues throughout the area. Led by President and CEO Steven Libman and Music Director Courtney Lewis, the Jacksonville Symphony reaches over 113,000 individuals through over 125 performances each season. In addition, the Symphony provides music instruction for youth and operates the Jacksonville Symphony Youth Orchestras. For more information about the Symphony, visit JaxSymphony.org.\n\nAbout WJCT Public Media:\n\nWJCT is the community-owned and operated public media organization serving Jacksonville and the First Coast since 1958, using television, radio, digital media, and live events to help community members learn, share, and grow. For more information on WJCT's in-depth programming content, log on to WJCT Online at wjct.org. Like WJCT on Facebook (facebook.com/wjctjax) and follow WJCT on Twitter (@WJCTJax) and Instagram (@WJCTJax).\n\nThis press release was produced and distributed by the Jacksonville Symphony and WJCT Public Media.",
        "Coca-Cola Co., Cisco Systems Inc., and Stellantis NV will report earnings this week.\n\nAs earnings reports continue to roll in through the week, market watchers will tune in for the latest inflation numbers when the Consumer Price Index (CPI) is released Tuesday. After ticking higher last month, Federal Reserve officials are watching for more signs that inflation is continuing its downward trend.\n\nRetail sales numbers on Thursday will help show if consumers continued their strong shopping habits in January. Meanwhile, the homebuilder confidence index will indicate whether favorable residential construction trends continue.\n\nSeveral companies will report earnings this week, including Coca-Cola Co., Cisco Systems Inc., and Stellantis NV.\n\nAs the Federal Reserve closely watches the path of inflation, Tuesday's consumer price index should offer some clues as to whether price growth continues to slow.\n\nWhile inflation has been trending downward, the most recent CPI reading showed prices edging back higher in December, growing at a 3.4% annual rate. Since then, other inflation measurements have shown the deceleration of inflation, so investors will be watching to see if the trend continues.\n\nFederal Reserve voted to keep interest rates steady at its last meeting. Several officials said last week they would be closely watching inflation data to see if it continues to trend toward the target of 2%.\n\nA string of earnings reports this week will give investors a look at a wide swath of components of the economy, from consumer staples to commercial real estate.\n\nTwo constituents of the Dow Jones Industrial Average (DJIA) are set to issue their quarterly financial statements this week. Beverage giant Coca-Cola discloses whether it has continued its sales momentum on Tuesday while computer network equipment maker Cisco on Wednesday looks to rebound after reporting a slowdown in product orders last quarter.\n\nJeep maker Stellantis' report on Thursday comes after the vehicle maker negotiated a new contract with employees last fall, ending a six-week labor strike.\n\nJohn Deere's earnings on Thursday will give investors a window into the agricultural sector. Meanwhile, DoorDash earnings will show the strength of the gig economy as the food-delivery service app tries to add more users.\n\nAnother company investors may be eyeing is CBRE Group, a commercial real estate company that could shed some light on the sector with its Thursday earnings report. The industry's condition has created concerns that some regional banks like New York Community Bancorp Inc. (NYCB) are too exposed to weakness in the market.",
        "The Taiwan stock market has finished lower in two of three trading days since the end of the three-day winning streak in which it had rallied more than 270 points or 1.4 percent. The Taiwan Stock Exchange now sits just above the 18,935-point plateau and it figures to bounce higher again on Monday.\n\nThe global forecast for the Asian markets is upbeat, with support expected from the technology and oil companies. The European and U.S. markets were up and the Asian bourses figure to open in similar fashion.\n\nThe TSE finished slightly lower on Friday following losses from the financial shares, technology companies and plastics.\n\nFor the day, the index dipped 30.84 points or 0.16 percent to finish at 18,935.93 after trading between 18,923.46 and 19,041.92.\n\nAmong the actives, Cathay Financial dropped 0.89 percent, while Mega Financial fell 0.39 percent, CTBC Financial skidded 1.19 percent, First Financial eased 0.18 percent, Fubon Financial sank 0.88 percent, E Sun Financial collected 0.40 percent, Taiwan Semiconductor Manufacturing Company dipped 0.14 percent, United Microelectronics Corporation retreated 1.13 percent, Hon Hai Precision slumped 0.97 percent, Largan Precision shed 0.77 percent, MediaTek plunged 3.07 percent, Delta Electronics slid 0.34 percent, Novatek Microelectronics was down 0.33 percent, Formosa Plastics lost 0.14 percent, Nan Ya Plastics tanked 2.01 percent, Asia Cement declined 0.74 percent, China Steel shed 0.61 percent and Catcher Technology and Taiwan Cement were unchanged.\n\nThe lead from Wall Street is positive as the major averages opened flat on Friday but accelerated as the day progressed, sending the NASDAQ and S&P to record closing highs.\n\nThe Dow advanced 90.98 points or 0.23 percent to finish at 39,087.38, while the NASDAQ jumped 183.04 points or 1.14 percent to close at 16,274.94 and the S&P 500 rallied 40.81 points or 0.80 percent to end at 5,137.08. For the week, the NASDAQ shot up 1.7 percent and the S&P 500 rose 1.0 percent, but the Dow eased 0.1 percent.\n\nThe surge by the NASDAQ reflected substantial strength among computer hardware stocks following upbeat results from Dell (DELL), with the NYSE Arca Computer Hardware Index soaring to a record closing high.\n\nIn economic news, the Institute for Supply Management said manufacturing activity in the U.S. unexpectedly contracted at an accelerated rate in February. Also, the University of Michigan released revised data showing consumer sentiment unexpectedly deteriorated in February.\n\nThe soft data contributed to a downturn by treasury yields, which added to optimism about the Federal Reserve eventually cutting interest rates.\n\nOil prices rose to a four-month high on Friday, buoyed by reports that oil demand surged to a four-year high in 2023 and will hold near that level again this year. West Texas Intermediate Crude oil futures for April spiked $1.71 or 2.2 percent at $79.97 a barrel, the highest close since November 6, 2023.\n\nFor comments and feedback contact: editorial@rttnews.com",
        "Welcome to insideBIGDATA's \"Heard on the Street\" round-up column! In this regular feature, we highlight thought-leadership commentaries from members of the big data ecosystem. Each edition covers the trends of the day with compelling perspectives that can provide important insights to give you a competitive advantage in the marketplace. We invite submissions with a focus on our favored technology topics areas: big data, data science, machine learning, AI and deep learning. Click HERE to check out previous \"Heard on the Street\" round-ups.\n\nUse science and math when making infrastructure design decisions for LLMs. Commentary by Colleen Tartow, Ph.D., Field CTO and Head of Strategy, VAST Data\n\n\"When designing an AI system for training and fine-tuning LLMs, there is a lot of vendor-driven conversation that confounds the landscape. However, relying on common sense along with some math and science can get organizations far in a situation where small mistakes can be incredibly costly.For example, let's look at calculating the bandwidth necessary for checkpoint operations in a recoverable model. There are multiple modes of parallelism to consider in an LLM training environment, each of which makes recoverability more streamlined. Data parallelism takes advantage of many processors by splitting data into chunks, so any individual GPU is only training on a portion of the full dataset. Model parallelism is similar - the algorithm itself is sharded into discrete layers, or tensors, and then distributed across multiple GPUs or CPUs. Finally, pipeline parallelism splits the model training process into smaller steps and executes them independently on different processors. Combining these modes of parallelism ensures that recoverability is possible with a much smaller checkpoint overall. In fact, since the model and data are copied in full to each octet (group of 8 DGXs) and parallelized within the octet, only one checkpoint is needed per octet, which drastically reduces the bandwidth needed to write a checkpoint.This is an example of how understanding the intricate details of parallelism and LLM training can help organizations design a system that is well-built for checkpoint and recoverability operations. Given the scale of infrastructure required here, it is paramount to neither over- nor under-size resources to avoid overpaying for hardware (wasting money) nor underprovisioning the model architecture (negatively affecting deliverables). Simply put, organizations need to rely on real technical knowledge and calculations when designing an AI ecosystem.\"\n\nGenerative transformation is the future of the enterprise. Commentary by Kevin Cochrane, CMO, Vultr\n\n\"Gartner's annual IT Infrastructure, Operations & Cloud Strategies Conference explored the future of infrastructure operations, highlighting the biggest challenges and opportunities heading into 2024. One of the big themes for 2024? Generative transformation.\n\nEnterprises across industries - from healthcare and life sciences to financial services and media & entertainment - are racing to embrace AI transformation. However, the past year has highlighted the need for enterprises to actively pursue generative change to flourish in the evolving landscape of AI-driven business.\n\nGenerative transformation involves implementing both technological and organizational shifts to integrate generative AI into the fundamental aspects of business operations. The three foundational steps needed to achieve this include: formulating a strategy around how your enterprise will use generative AI, planning for the organizational change needed to fully roll out generative transformation, and building and deploying a platform engineering solution to empower the IT, operations and data science teams supporting your generative transformation journey.\n\nWith these three steps, enterprises will be well on their way to diving head first into generative transformation, and ultimately thriving in today's dynamic business landscape.\"\n\nGPT store allows for better ChatGPT user experience. Commentary by Toby Coulthard, CPO at Phrasee\n\n\"There's been interesting discourse in the AI 'hypefluencer' space (namely on X) that paints GPTs as glorified instruction prompts and provide no more capability or functionality than before, and therefore provide no utility. They're missing the point; this is a user experience change, not a capability one. A large part of what OpenAI has been struggling with is that most people beyond the early adopters of ChatGPT don't know what to do with it. There's nothing scarier than a flashing cursor in a blank field. ChatGPTs 'chasm' in the product adoption curve is that these early majority users want to use ChatGPT but don't know how. No one was sharing prompts before, now they're sharing GPTs, and the GPT Store facilitates that. The GPT Store opens the door to the next 100m+ weekly active users.\n\nWith the recent launch, I expect there to be a few very profitable GPTs, with a very large, long-tail of GPTs that are free to use. Plugins will allow for further monetization through third-party services via APIs, but that's further down the line.\n\nThe comparison with an 'app store' is misguided, OpenAI isn't facilitating the dissemination of applications, they're facilitating the dissemination of workflows. Principally from the most advanced ChatGPT users with experience in prompt engineering, to the least. It's improving the usability and accessibility of ChatGPT, and its intention is increased adoption and improved retention - in that regard it will improve OpenAI's competitiveness. They also act as 'agents lite'. OpenAI has even admitted this is a first step towards autonomous agents. They have a reputation of releasing earlier versions to democratize the ideation of use cases - both beneficial and harmful to inform where the product should go. OpenAI is aware that even they don't know all the use cases for their models - the GPT Store enables them to see what people produce and what's useful, popular, and potentially dangerous before they build in more capability and autonomy to these GPTs. The challenges lie in the edge-cases that OpenAI is yet to think of.\"\n\nThe Information Commissioner's Office (ICO) in the UK is investigating the legality of web scraping for collecting data used in training generative AI models. Commentary by Michael Rinehart, VP of AI, Securiti\n\n\"Enacted on May 25, 2018, the EU General Data Protection Regulation (GDPR) is having a profound impact on the enforcement of global privacy regulations. Emphasizing the importance of obtaining consent before processing information, GDPR is even more relevant today than it was six years ago when it was first implemented. In this evolving landscape, the surge of AI has fundamentally altered how data is handled, further reinforcing the significance of adhering to these laws. The recent investigation by the UK's Information Commissioner's Office (ICO) into the legality of web scraping for training generative AI models is therefore unsurprising. These models generate text or images based on large datasets, raising privacy concerns due to automated data collection.\n\nThe ICO's focus on data protection standards aligns with GDPR principles. Responsible AI implementation requires robust data governance practices. As AI systems continue to be integrated with sensitive data, organizations must establish strong controls, including strict access control, anonymization, and governance frameworks to optimally balance AI potential with data privacy and security.\"\n\nLacking Proper Data Governance, 'Black Box' AI Could Be Disastrous for the Enterprise. Commentary by John Ottman, Executive Chairman of Solix Technologies, Inc\n\n\"Over the past year OpenAI's ChatGPT has dominated the press, business discussions and influenced every company's stance and guidelines on the use of generative AI. The impact has been profound as the entire world has now largely seen how generative AI automates repetitive or difficult tasks, reduces workloads and simplifies processes. But more recently, concerns have arisen over enterprise use of ChatGPT, noting the data governance challenges caused by exposing enterprise data to 'black box' AI and 'being too reliant on one company's AI tech.'\n\nEnterprise AI users are concerned that the risks posed by 'black box' AI models are just too great, and some have already banned their use. Chief amongst the list of concerns are data security, data privacy and compliance with laws regulating the handling of sensitive data and personally identifiable information (PII). Others even worry that ChatGPT would become so integral to their business that a failure at OpenAI would lead to a failure at their business as well.\n\nIt's an unavoidable conclusion that training an external, proprietary 'black box' AI model with your private enterprise data is dangerous and may expose your company to data breach, legal risk and compliance findings. 'Black box' training inputs and operations aren't visible for peer review and prompts may arrive at conclusions or decisions without providing any explanation as to how they were reached. ChatGPT introduced the world to generative AI, but so far data governance concerns rule out a central role in the enterprise.\n\nIn the wake of ChatGPT, private LLMs have emerged as a leading alternative for enterprise use because they are safe, secure, affordable and solve the operational challenge of training public LLMs with private enterprise data. Private AI models reduce the risk of data exfiltration and adverse security and compliance findings because the data never leaves the enterprise. Several of the world's most powerful LLMs are available as free and open source solutions, providing improved transparency and control over security and compliance. Most importantly, private LLMs may be safely and securely trained and fine-tuned with enterprise data.\"\n\nOpen vs. Closed AI Heats up with New AI Alliance. Commentary by Mike Finley, CTO and co-Founder, AnswerRocket\n\n\"After Meta, IBM and Intel recently launched the AI Alliance, the battle between open and closed AI has begun to heat up. Closed AI took a big lead out of the gate, with technologies like ChatGPT (ironically from OpenAI) and Bard delivering a practical, powerful chatbot experience and are being leveraged by many businesses. Meanwhile, open AI offerings like Llama are rough around the edges, suffer from inferior performance and have been sparsely adopted within the enterprise.\n\nHowever, the AI Alliance shows that open AI may start competing quicker than most expected - and growing community and vendor support is the reason why. The three partners in the alliance are playing catch up after being sidelined in AI (Watson \"lost\" to GPT, Intel \"lost\" to NVIDIA, and Meta's Llama 2 is about six months behind OpenAI in terms of creativity, token sizes, task complexity, ease of use, and pretty much everything except cost). So the three are well resourced, capable, and motivated.\n\nUltimately, the race between the two will bear similarities to the iPhone vs. Android battle. The closed AI technologies will provide a premium, highly polished, easily usable products. Open AI tech will offer great value, flexibility and support for niche applications.\"\n\nData sovereignty has gone viral. Commentary by Miles Ward, CTO of SADA\n\n\"Imagine you are building your business, making promises to customers and you get hacked! Not your fault, but your provider doesn't see it that way and ignores your request for support, so you must take legal action. But wait, your provider is owned by different legal systems and different contract rules - if you think local lawyers are expensive, think international expense.\n\nCompanies want the relationships they have with customers governed under the same laws as they are, meaning they'll want the data protected by those laws, which in most cases means it needs to be stored in the same country where they're doing business. The challenge there is that there are 192 countries and there are far from 192 cloud providers.\"\n\nWhy PostgreSQL continues to be the fastest growing DBMS. Extensibility. Commentary by Charly Batista, PostgreSQL Technical Lead at Percona\n\n\"In the past year, PostgreSQL has not merely maintained but strengthened its position as one of the fastest growing database management systems in the world -- continuing to enjoy rapid, sustained growth in overall adoption, as well as being named 2023's DBMS of The Year by DB-Engines for the fourth time in just the past six years (which uses a variety of metrics, such as growth in web citations and professional profile entries, to determine which DBMS saw the greatest increase in popularity over the past year).\n\nWhile the DBMS has a variety of advantageous qualities, one of the main driving forces behind PostgreSQL's enduring success lies in its unparalleled extensibility. Extensibility, in this case, refers to the ability of the database management system to be easily extended or customized to accommodate new features, data types, functions, and behaviors. Through that extensibility, PostgreSQL gives developers the flexibility to continually re-tool and expand upon the functionality of the DBMS as their needs and those of the market change. As a result, PostgreSQL promises what other DBMS's can't -- seamless adaptation to diverse user requirements, and the ability to keep pace with an ever-evolving technological landscape; both of which have proven particularly advantageous as of late in relation to the booming fields of machine learning and AI.\n\nCombined with this extensibility, PostgreSQL's open-source nature implicitly provides immense opportunity. With countless extensions already freely available and permissive licensing that encourages experimentation, PostgreSQL has become a hotbed for innovation. Developers are able to consistently push the boundaries of what a single database management system can do. This open ethos invites engagement, participation, and contributions, from a multitude of sources, organizations and individuals alike, leading to a rich, diverse pool of talent and expertise.\n\nThe synergy between PostgreSQL's extensibility and open-source foundation has played a central role in propelling it to become one of the fastest-growing DBMSs on the market, and one of the most beloved. In a way, it has evolved beyond a mere database management system, instead manifesting into a platform where developers can adapt and create a DBMS that fits their specific needs. Thanks to PostgreSQL's convergence of open-source principles and extensibility, developers have a platform for the continuous exchange of ideas, extensions, and shared indexes. PostgreSQL, thus, stands not just as a database of choice but as a testament to the power of collaboration, adaptability, and innovation in the ever-expanding realm of database technology.\"\n\nBalancing the Environmental Impact of Data Mining. Commentary by Neil Sahota, Chief Executive Officer ACSILabs Inc & United Nations AI Advisor\n\n\"Like the two sides of a coin, data mining has both positive and negative environmental impacts. Thus, it's a balance between resource optimization and environmental monitoring and the contrast with significant energy consumption and potential for data misuse.\n\nOn the positive side, data mining optimizes resource management. For example, it aids in predictive maintenance of infrastructure, reducing the need for excessive raw materials. In agriculture, precision farming techniques (reliant on data mining) optimize the use of water and fertilizers, enhancing sustainability. A study by the USDA showed that precision agriculture could reduce fertilizer usage by up to 40%, significantly lowering environmental impact. Second, data mining plays a crucial role in environmental conservation. By monitoring and analyzing large data sets, researchers track changes in climate patterns, biodiversity, and pollution levels. The Global Forest Watch, for instance, has leveraged data mining to provide insights into forest loss.\n\nConversely, there are three crucial negative impacts. First is the high energy consumption. Data centers are essential for data mining but consume vast amounts of energy. According to a report by the International Energy Agency, data centers worldwide consumed about 200 TWh in 2020, which is roughly 1% of global electricity use. This consumption contributes to greenhouse gas emissions, particularly if the energy is sourced from fossil fuels.\n\nSecond is e-waste and resource depletion. Hardware used in data mining (e.g. servers) has a finite lifespan, leading to electronic waste. Moreover, manufacturing these devices also contributes to the depletion of rare earth minerals. The United Nations University estimates that global e-waste reached 53.6 million metric tons in 2019, a figure that continually rises because of increasing demand for data processing infrastructure.\n\nThird is the potential for data misuse. While not a direct environmental impact, this data misuse can lead to misguided policies or exploitation of natural resources. Ensuring ethical and sustainable use of data is crucial to prevent negative environmental consequences. While data mining offers significant environmental and resource optimization benefits, its environmental footprint cannot be overlooked. Balancing the advantages with sustainable practices while minimizing its negative environmental impacts is essential for producing true positive net value.\"\n\nHow AI hallucinations are unpredictable, yet avoidable. Commentary by Ram Menon; Founder and CEO of Avaamo\n\n\"The phenomenon of hallucinations in large language models (LLMs) stems primarily from the limitations imposed by their training datasets. If an LLM is trained on data lacking the necessary knowledge to address a given question, it may resort to generating responses based on incomplete or incorrect information, leading to hallucinations. However, this is just one facet of the challenge. Complications arise due to the LLMs' inability to verify the factual accuracy of its responses, often delivering convincing yet erroneous information. Additionally, the training datasets may contain a mix of fictional content and subjective elements like opinions and beliefs, further contributing to the complexity. The absence of a robust mechanism for admitting insufficient information can aggravate the issue, as the LLM tends to generate responses that are merely probable, not necessarily true, resulting in hallucinations.\n\nTo mitigate hallucinations in enterprise settings, companies have found success through an innovative approach known as Dynamic Grounding, which incorporates retrieval augmented generation (RAG), which supplements the LLM's knowledge from its training dataset with information retrieved from secure and trusted enterprise data sources.",
        "CALGARY, Alberta--(BUSINESS WIRE)--Feb 22, 2024--\n\nPembina Pipeline Corporation (\"Pembina\" or the \"Company\") (TSX: PPL; NYSE: PBA) announced today its financial and operating results for the fourth quarter and full year 2023.\n\nThis press release features multimedia. View the full release here: https://www.businesswire.com/news/home/20240222955162/en/\n\nHighlights\n\nRecord Results - reported 2023 full year earnings of $1,776 million and record full year adjusted EBITDA of $3,824 million that exceeded the high-end of the Company's original 2023 guidance range. Reported fourth quarter earnings of $698 million and record quarterly adjusted EBITDA of $1,033 million.Ethane Supply and Transportation Agreements - Pembina has entered into long-term agreements with Dow Chemical Canada (\"Dow\") to supply and transport up to 50,000 barrels per day (\"bpd\") of ethane to support their recently announced Path2Zero Project.Nipisi Pipeline Contracting - signed an incremental long-term contract on the recently reactivated Nipisi Pipeline, with line of sight to the asset being fully contracted by the end of 2024.Wapiti Expansion - Pembina Gas Infrastructure (\"PGI\") has approved a $140 million (net to Pembina) expansion of the Wapiti Plant that will increase natural gas processing capacity by 115 million cubic feet per day (\"mmcf/d\") (gross to PGI).Phase VIII Peace Pipeline Expansion - the estimated project cost has been further reduced to $430 million (previously $475 million; original budget of $530 million).Common Share Dividend - the board of directors declared a common share cash dividend for the first quarter of 2024 of $0.6675 per share, to be paid, subject to applicable law, on March 28, 2024, to shareholders of record on March 15, 2024.Strong Balance Sheet - at December 31, 2023 the ratio of proportionately consolidated debt-to-adjusted EBITDA was 3.3 times, below the low end of the Company's targeted range.\n\nFinancial and Operational Overview\n\n3 Months Ended December 31\n\n12 Months Ended December 31\n\n($ millions, except where noted)\n\n2023\n\n2022\n\n2023\n\n2022\n\nRevenue\n\n2,466\n\n2,699\n\n9,125\n\n11,611\n\nNet revenue (1)\n\n1,117\n\n1,043\n\n3,994\n\n4,247\n\nGross profit\n\n850\n\n681\n\n2,840\n\n3,123\n\nAdjusted EBITDA (1)\n\n1,033\n\n925\n\n3,824\n\n3,746\n\nEarnings\n\n698\n\n243\n\n1,776\n\n2,971\n\nEarnings per common share - basic (dollars)\n\n1.21\n\n0.39\n\n3.00\n\n5.14\n\nEarnings per common share - diluted (dollars)\n\n1.21\n\n0.39\n\n2.99\n\n5.12\n\nCash flow from operating activities\n\n880\n\n947\n\n2,635\n\n2,929\n\nCash flow from operating activities per common share - basic (dollars)\n\n1.60\n\n1.72\n\n4.79\n\n5.30\n\nAdjusted cash flow from operating activities (1)\n\n747\n\n690\n\n2,646\n\n2,661\n\nAdjusted cash flow from operating activities per common share - basic (dollars)(1)\n\n1.36\n\n1.25\n\n4.81\n\n4.82\n\nCapital expenditures\n\n177\n\n143\n\n606\n\n605\n\nTotal volumes (mboe/d)(2)\n\n3,453\n\n3,392\n\n3,306\n\n3,383\n\n(1) Refer to \"Non-GAAP and Other Financial Measures\".\n\n(2) Total revenue volumes. Revenue volumes are physical volumes plus volumes recognized from take-or-pay commitments. Volumes are stated in thousand barrels of oil equivalent per day (\"mboe/d\"), with natural gas volumes converted to mboe/d from millions of cubic feet per day (\"MMcf/d\") at a 6:1 ratio, and also include revenue volumes from Pembina's equity accounted investees.\n\nFinancial and Operational Overview by Division\n\n3 Months Ended December 31\n\n12 Months Ended December 31\n\n2023\n\n2022\n\n2023\n\n2022\n\n($ millions, except where noted)\n\nVolumes (1)\n\nReportable Segment Earnings (Loss) Before Tax\n\nAdjusted EBITDA (2)\n\nVolumes (1)\n\nReportable Segment Earnings (Loss) Before Tax\n\nAdjusted EBITDA (2)\n\nVolumes (1)\n\nReportable Segment Earnings (Loss) Before Tax\n\nAdjusted EBITDA (2)\n\nVolumes (1)\n\nReportable Segment Earnings (Loss) Before Tax\n\nAdjusted EBITDA (2)\n\nPipelines\n\n2,652\n\n677\n\n617\n\n2,593\n\n295\n\n548\n\n2,538\n\n1,840\n\n2,234\n\n2,524\n\n1,415\n\n2,127\n\nFacilities\n\n801\n\n143\n\n324\n\n799\n\n145\n\n288\n\n768\n\n610\n\n1,213\n\n859\n\n1,804\n\n1,137\n\nMarketing & New Ventures\n\n--\n\n204\n\n173\n\n--\n\n96\n\n171\n\n--\n\n435\n\n597\n\n--\n\n708\n\n721\n\nCorporate\n\n--\n\n(209)\n\n(81)\n\n--\n\n(206)\n\n(82)\n\n--\n\n(696)\n\n(220)\n\n--\n\n(708)\n\n(239)\n\nTotal\n\n3,453\n\n815\n\n1,033\n\n3,392\n\n330\n\n925\n\n3,306\n\n2,189\n\n3,824\n\n3,383\n\n3,219\n\n3,746\n\n(1) Volumes for Pipelines and Facilities divisions are revenue volumes, which are physical volumes plus volumes recognized from take-or-pay commitments. Volumes are stated in mboe/d, with natural gas volumes converted to mboe/d from MMcf/d at a 6:1 ratio. Volumes do not include Empress processing capacity. Marketed natural gas liquids (\"NGL\") volumes are excluded from volumes to avoid double counting. Refer to \"Marketing & New Ventures Division\" in Pembina's Management's Discussion and Analysis dated February 22, 2024 for the three and twelve months ended December 31, 2023 for further information.\n\n(2) Refer to \"Non-GAAP and Other Financial Measures\".\n\nFor further details on the Company's significant assets, including definitions for capitalized terms used herein that are not otherwise defined, refer to Pembina's Annual Information Form for the year ended December 31, 2023 filed at www.sedarplus.ca (filed with the U.S. Securities and Exchange Commission at www.sec.gov under Form 40-F) and on Pembina's website at www.pembina.com.\n\nFinancial & Operational Highlights\n\nAdjusted EBITDA\n\nPembina reported record quarterly adjusted EBITDA of $1,033 million in the fourth quarter and record full year adjusted EBITDA of $3,824 million. This represents a $108 million or 12 percent increase, and a $78 million or two percent increase, respectively, over the same periods in the prior year. For both the fourth quarter and full year, reported adjusted EBITDA reflects strong performance in the Pipelines and Facilities divisions as Pembina continues to benefit from growing volumes and higher tolls on certain systems, as well as continued strong results from the marketing business.\n\nPipelines reported adjusted EBITDA of $617 million for the fourth quarter, representing a $69 million or 13 percent increase compared to the same period in the prior year, reflecting the net impact of the following factors:\n\nhigher volumes on the Peace Pipeline system, Drayton Valley Pipeline, and on the recently reactivated Nipisi Pipeline;higher tolls primarily on the Cochin Pipeline and Peace Pipeline systems, largely related to contractual inflation adjustments; andlower contribution from the Alliance Pipeline, primarily due to lower interruptible tolls and volumes.\n\nPipelines reported adjusted EBITDA of $2,234 million for the full year, representing a $107 million or five percent increase compared to the same period in the prior year, reflecting the net impact of the following factors:\n\nhigher contracted volumes and tolls on the Peace Pipeline system;higher tolls and the impact of a higher U.S. dollar exchange rate on the Cochin Pipeline;higher volumes on the Vantage Pipeline due to third party outages in 2022;reactivation of the Nipisi Pipeline;lower volumes and higher operating costs due to the Northern Pipeline system outage and the Alberta and British Columbia wildfires (the \"Wildfires\"); andlower contribution from the Alliance Pipeline, primarily due to the sale of linepack inventory in 2022, lower interruptible tolls and volumes, and seasonal contracts being replaced by firm contracts at lower regulated rates.\n\nFacilities reported adjusted EBITDA of $324 million for the fourth quarter, representing a $36 million or 13 percent increase over the same period in the prior year, reflecting the net impact of the following factors:\n\nhigher contribution from the PGI assets, primarily from the former Energy Transfer Canada plants, the Hythe Plant, and the Dawson Assets due to higher volumes; andhigher revenue at Vancouver Wharves.\n\nFacilities reported adjusted EBITDA of $1,213 million for the full year, representing a $76 million or seven percent increase over the same period in the prior year, reflecting the net impact of the following factors:\n\nhigher contribution from the PGI assets, due to higher volumes primarily at the former Energy Transfer Canada plants, the Hythe Plant, and the Dawson Assets;a gain on the recognition of a finance lease; andlower volumes at the Redwater Complex and at Younger primarily due to the Northern Pipeline system outage.\n\nMarketing & New Ventures reported adjusted EBITDA of $173 million for the fourth quarter, representing a $2 million or one percent increase compared to the same period in the prior year, reflecting the net impact of the following factors:\n\nhigher contribution from Aux Sable;lower natural gas marketing margins due to the decrease in Chicago natural gas prices, as well as lower crude oil margins resulting from the lower prices across the crude oil complex, largely offset by higher NGL margins, primarily due to lower input natural gas prices and higher marketed NGL volumes; andrealized losses on commodity-related derivatives in the fourth quarter of 2023 compared to realized gains in the fourth quarter of 2022.\n\nMarketing & New Ventures reported adjusted EBITDA of $597 million for the full year, representing a $124 million or 17 percent decrease compared to the same period in the prior year, reflecting the net impact of the following factors:\n\nlower crude oil, NGL, and natural gas margins, resulting from a decrease in commodity prices;lower contribution from Aux Sable; andrealized gains on commodity-related derivatives in 2023, compared to realized losses in 2022.\n\nCorporate reported adjusted EBITDA of negative $81 million for the fourth quarter, which was largely consistent with the same period in the prior year. Results were impacted by higher incentive costs driven by Pembina's share price performance and increased shared service revenue.\n\nCorporate reported adjusted EBITDA of negative $220 million for the full year, representing an $19 million or eight percent increase over the same period in the prior year, reflecting the net impact of the following factors:\n\nlower general and administrative costs, net of increased shared service revenue; andlower long-term incentive costs.\n\nEarnings\n\nPembina reported fourth quarter earnings of $698 million and full year earnings of $1,776 million. This represents a $455 million or 187 percent increase, and a $1,195 million or 40 percent decrease, respectively, over the same periods in the prior year.\n\nPipelines had reportable segment earnings before tax in the fourth quarter of $677 million, representing a $382 million or 129 percent increase over the prior period. In addition to the factors impacting adjusted EBITDA, as noted above, the change in reportable segment earnings before tax in the fourth quarter was due to the reversal of a previous impairment related to the Nipisi Pipeline, as well as the Ruby settlement provision and associated legal fees incurred in the fourth quarter of 2022.\n\nPipelines had reportable segment earnings before tax for the full year of $1,840 million, representing a $425 million or 30 percent increase over the prior year. In addition to the factors impacting adjusted EBITDA and the factors impacting fourth quarter reportable segment earnings before tax, as noted above, the change in reportable segment earnings before tax for the full year was due to higher depreciation.\n\nFacilities had reportable segment earnings before tax in the fourth quarter of $143 million representing a $2 million or one percent decrease over the prior year. In addition to the factors impacting adjusted EBITDA, as noted above, the change in reportable segment earnings before tax in the fourth quarter was due to lower project write-offs recognized in the quarter, largely offset by higher depreciation.\n\nFacilities had reportable segment earnings before tax for the full year of $610 million representing a $1,194 million or 66 percent decrease over the prior year. In addition to the factors impacting adjusted EBITDA, as noted above, the change in reportable segment earnings before tax for the full year was due to the $1.1 billion gain recognized on the PGI Transaction during the third quarter of 2022, partially offset by lower depreciation and lower project write-offs.\n\nMarketing & New Ventures had reportable segment earnings before tax in the fourth quarter of $204 million representing a $108 million or 113 percent increase over the prior year. In addition to the factors impacting adjusted EBITDA, as noted above, the change in reportable segment earnings before tax in the fourth quarter was due to an unrealized gain on commodity-related derivatives compared to a loss in the fourth quarter of 2022, lower net finance costs due to decreased foreign exchange losses, and a change in the insurance contract provision in the period.\n\nMarketing & New Ventures had reportable segment earnings before tax for the full year of $435 million representing a $273 million or 39 percent decrease, over the prior year. In addition to the factors impacting adjusted EBITDA, as noted above, the change in reportable segment earnings before tax in the full year was due to an unrealized loss on commodity-related derivatives compared to a gain in 2022, partially offset by lower net finance costs due to gains recognized on non-commodity related derivatives compared to losses in 2022.\n\nIn addition to the changes in reportable segment earnings before tax for each division discussed above, the change in fourth quarter earnings compared to the prior period was due to higher income tax expense due to higher earnings compared to the prior period, partially offset by the recognition of previously unrecognized deferred tax assets. The change in the full year earnings compared to the prior year was also primarily due to higher income tax expense due to the tax impact of the PGI Transaction in 2022.\n\nCash Flow From Operating Activities\n\nCash flow from operating activities of $880 million for the fourth quarter and $2,635 million for the full year represent a seven percent and ten percent decrease, respectively, over the same periods in the prior year.\n\nThe decrease in the fourth quarter was primarily driven by the change in non-cash working capital, higher taxes paid, and a decrease in payments collected through contract liabilities, partially offset by higher operating results.\n\nThe decrease in the full year was primarily driven by the change in non-cash working capital, lower operating results, a decrease in payments collected through contract liabilities, and higher share-based compensation payments, partially offset by higher distributions from equity accounted investees and lower taxes paid.\n\nOn a per share (basic) basis, cash flow from operating activities was $1.60 per share for the fourth quarter and $4.79 per share for the full year. This represents decreases of seven percent and ten percent, respectively, compared to the same periods in the prior year.\n\nAdjusted Cash Flow From Operating Activities\n\nAdjusted cash flow from operating activities of $747 million for the fourth quarter and $2,646 million for the full year, represent an eight percent increase and one percent decrease, respectively, over the same periods in the prior year.\n\nThe increase in the fourth quarter was primarily driven by the same items impacting cash flow from operating activities, discussed above, excluding the change in non-cash working capital and taxes paid, partially offset by higher current income tax expense.\n\nThe decrease in the full year was primarily driven by the same items impacting cash flow from operating activities, discussed above, excluding the change in non-cash working capital, taxes paid, and share-based compensation payments, combined with higher current tax expense, partially offset by lower accrued share-based payment expense.\n\nOn a per share (basic) basis, adjusted cash flow from operating activities was $1.36 per share for the fourth quarter and $4.81 per share for the full year. This represents an increase of nine percent and no change, respectively, compared to the same periods in the prior year.\n\nVolumes\n\nTotal volumes of 3,453 mboe/d for the fourth quarter and 3,306 mboe/d for the full year represent an increase of two percent and a decrease of two percent, respectively, over the same periods in the prior year.\n\nPipelines volumes of 2,652 mboe/d in the fourth quarter represent a two percent increase compared to the same period in the prior year, primarily reflecting the reactivation of the Nipisi Pipeline in the fourth quarter of 2023, higher contracted volumes on the Peace Pipeline system, as well as higher volumes on the Drayton Valley Pipeline.\n\nPipelines volumes of 2,538 mboe/d for the full year represent a one percent increase compared to the same period in the prior year, primarily reflecting higher contracted volumes on the Peace Pipeline system, the reactivation of the Nipisi Pipeline in the fourth quarter of 2023, and higher volumes on the Vantage Pipeline due to third-party outages in 2022, partially offset by lower volumes related to the Northern Pipeline system outage, and the impacts of the Wildfires.\n\nFacilities volumes of 801 mboe/d in the fourth quarter were consistent with the same period in the prior year, reflecting higher volumes from PGI, primarily at the Hythe Gas Plant and at the Dawson Assets, largely offset by lower volumes at the Redwater Complex.\n\nFacilities volumes of 768 mboe/d for the full year represent an 11 percent decrease compared to the same period in the prior year, reflecting the net impact of the following factors:\n\nthe disposition of Pembina's interest in the E1 and E6 assets in exchange for a processing agreement that provides Pembina with the right to first priority for gas processing at all Plains Midstream-operated assets at Empress;lower volumes at the Redwater Complex and at Younger resulting from the Northern Pipeline system outage and planned outages in the third quarter of 2023; andhigher volumes from PGI, primarily at the former Energy Transfer Canada plants and at the Dawson Assets.\n\nExcluding the impact of the disposition of Pembina's interest in the E1 and E6 assets at Empress, the Northern Pipeline system outage, and the Wildfires, Facilities volumes would have increased by five percent in 2023 compared to the same period in the prior year.\n\nMarketed NGL volumes of 217 mboe/d in the fourth quarter represents a 12 percent increase compared to the same period in the prior year, reflecting higher propane, ethane, and butane sales.\n\nMarketed NGL volumes of 185 mboe/d in the full year were largely consistent with the same period in the prior year.\n\nQuarterly Common Share Dividend\n\nPembina's board of directors has declared a common share cash dividend for the first quarter of 2024 of $0.6675 per share, to be paid, subject to applicable law, on March 28, 2024, to shareholders of record on March 15, 2024. The common share dividends are designated as \"eligible dividends\" for Canadian income tax purposes. For non-resident shareholders, Pembina's common share dividends should be considered \"qualified dividends\" and may be subject to Canadian withholding tax.\n\nFor shareholders receiving their common share dividends in U.S. funds, the cash dividend is expected to be approximately U.S. $0.4940 per share (before deduction of any applicable Canadian withholding tax) based on a currency exchange rate of 0.7401. The actual U.S. dollar dividend will depend on the Canadian/U.S. dollar exchange rate on the payment date and will be subject to applicable withholding taxes.\n\nQuarterly dividend payments are expected to be made on the last business day of March, June, September and December to shareholders of record on the 15th day of the corresponding month, if, as and when declared by the board of directors. Should the record date fall on a weekend or on a statutory holiday, the record date will be the next succeeding business day following the weekend or statutory holiday.\n\nExecutive Overview\n\n2023 results reflect the strength of Pembina's business and are highlighted by record annual adjusted EBITDA of $3.8 billion that exceeded the high end of our original guidance range. These results reflect growing volumes across many systems and a strong contribution from the marketing business. While operations in the first half of the year were impacted by the Wildfires and the Northern Pipeline system outage, the second half of the year more accurately reflected the underlying positive momentum in the Western Canadian Sedimentary Basin (the \"WCSB\"). This is demonstrated most notably by the more than four percent year-over-year increase in second half volumes in the conventional pipelines business.\n\nProgressing Pembina's Strategy\n\nIn early 2023, Pembina outlined a strategy designed to ensure it remains resilient into the future. Guided by this strategy, we are working every day to strengthen our existing business to ensure we help meet the energy needs of today and maximize the value of oil and gas products from Western Canada by getting them to the best markets in the world. We also recognize that the future of energy will require lower emissions and new energy solutions - there is a tremendous opportunity for Pembina to leverage its existing core business to help meet that challenge. Furthermore, our strategy demonstrates the value we place on doing this important work in a way that benefits everyone that has a stake in Pembina's business - our investors, customers, employees, and communities.\n\nA highlight of the fourth quarter was the announcement of a $3.1 billion acquisition of Enbridge's interests in Alliance, Aux Sable, and NRGreen joint ventures (the \"Alliance/Aux Sable Acquisition\"). Pembina's business is built around integrated, difficult-to-replicate assets that provide an enduring competitive advantage and unequaled market access for customers. Alliance Pipeline and Aux Sable are world-class energy infrastructure assets and increasing our existing ownership in them will further strengthen our growing franchise. The Alliance/Aux Sable Acquisition complements Pembina's strategy of providing access for world-class, long-life resources from the WCSB to premium end markets and increases exposure to lighter hydrocarbons, including natural gas and natural gas liquids. The Alliance/Aux Sable Acquisition is subject to the satisfaction or waiver of customary closing conditions, including the receipt of required regulatory approvals. The 30-day waiting period under U.S. Hart-Scott-Rodino Act has expired without any further queries from the applicable regulators. Pembina continues to expect the Alliance/Aux Sable Acquisition to close in the first half of 2024.\n\nIn 2023, Pembina further progressed its strategy by sustaining and enhancing our business through various previously disclosed accomplishments. These include signing new contracts on the Peace Pipeline system; signing new, or extending existing, contracts at the Redwater Complex; reactivating the Nipisi Pipeline; and approving new projects such as the 55,000 bpd RFS IV expansion, the expansion of the NEBC pipeline system, and a cogeneration facility at PGI's Kaybob 3 Plant.\n\nIn addition, Pembina is pleased to provide the following business updates:\n\nPGI has approved an expansion (the \"Wapiti Expansion\") that will increase natural gas processing capacity at the Wapiti Plant by 115 mmcf/d (gross to PGI). The Wapiti Plant is fully integrated into Pembina's value chain and the liquids processed at the plant are transported on the Peace Pipeline system. The Wapiti Expansion is being driven by strong customer demand supported by growing Montney production and will be fully underpinned by long-term, take-or-pay contracts. The Wapiti Expansion, which includes a new sales gas pipeline and other related infrastructure, is expected to cost $140 million (net to Pembina) with an estimated in-service date in the first half of 2026, subject to regulatory and environmental approval.In November, Dow announced it is proceeding with construction of a new integrated ethylene cracker and derivatives facility in Fort Saskatchewan (the \"Path2Zero Project\"), which is scheduled be completed in two phases with in-service dates in 2027 and 2029, respectively. This is an important development for the WCSB, representing a significant increase to the current ethane market in Alberta. Given Pembina's existing leading ethane supply and transportation business and extensive and integrated value chain, there are multiple opportunities for the Company to benefit from this new development, through both the existing asset base and new investment opportunities.\n\nFirst, Pembina is excited to announce that it has entered into long-term agreements with Dow to supply up to 50,000 bpd of ethane and for the associated transportation on the Alberta Ethane Gathering System (\"AEGS\").\n\nSecond, Pembina is a major supplier of ethane to the petrochemical industry. To expand its existing ethane supply portfolio, in support of the agreement with Dow, Pembina is evaluating several possible options to invest in new infrastructure, including incremental deep-cut processing capacity at certain PGI gas plants, de-ethanizer expansions at existing fractionation facilities, potential new straddle facilities, and smaller capital efficient expansion opportunities.\n\nFinally, the Path2Zero Project will directly drive incremental ethane demand, the extraction of which should also increase the supply of other associated NGL - propane, butane and condensate. The resulting volume growth across the WCSB will benefit Pembina over a period of many years and support higher utilization and potential expansions of its assets, including gas processing facilities, the Redwater fractionation complex, the Peace and Northern pipeline systems, the AEGS, and storage facilities.Pembina recently closed open seasons on the Cochin Pipeline for a total of 90,000 bpd with contracts expiring between 2027 and 2030, in respect of contracts previously expiring in July 2024. The open seasons were more than three times oversubscribed, highlighting strong customer interest and the value of Cochin Pipeline service. Cochin Pipeline, which spans from Illinois to Alberta, supplies light condensate to fill a structural diluent shortfall in the WCSB. The desire of shippers to secure long-term capacity highlights the important role that Cochin Pipeline plays in supporting the Canadian oil industry's operations, development, and growth. While contracted tolls are lower than historic levels, Pembina has successfully increased daily volume throughput over the past two years by up to 25,000 bpd, or approximately 25 percent, through operational optimization and equipment upgrades.Given rising production from the Clearwater oil play, Pembina continues to experience strong demand for service on the Nipisi Pipeline, with current volumes of approximately 33,000 bpd. Including an incremental contract signed with an anchor customer in the fourth quarter, more than half of the capacity on the Nipisi Pipeline is now contracted, on a long-term basis, with line of sight to the asset being fully contracted by the end of 2024.\n\nLooking Ahead to 2024 and Beyond\n\nMomentum within our business is expected to continue and Pembina is well positioned to benefit from what it expects to be a transformational period in the Canadian energy industry.\n\nIn 2024, Pembina will focus on progressing its current growth projects - the Phase VIII Peace Pipeline expansion, RFS IV, the K3 Cogeneration Facility, the Wapiti Expansion and the NEBC MPS Expansion - and delivering them on time and on budget. We also look forward to progressing our other development opportunities, such as Cedar LNG, the Alberta Carbon Grid, and further expansions of assets in our core business. As well, upon closing of the Alliance/Aux Sable Acquisition, we will prioritize integrating those businesses and pursuing the near-term synergies we have identified to extract greater value from these exceptional assets.\n\nIn December, Pembina announced a 2024 adjusted EBITDA guidance range of $3.725 billion to $4.025 billion, driven by continued volume growth across the WCSB, new assets placed into service, re-contracting of certain assets, and the prevailing commodity price outlook at the time. This guidance range excludes the impact of the recently announced Alliance/Aux Sable Acquisition. Pembina will provide further updates to the guidance range as timing of the closing of the Alliance/Aux Sable Acquisition becomes more certain.\n\nThroughout 2022 and 2023, Pembina has generated substantial free cash flow, which has been allocated to strengthening the balance sheet and returning capital to shareholders. During this time, Pembina has paid down debt, reducing leverage below the low end of its target range in anticipation of funding future capital projects. Pembina expects to remain firmly within its financial guardrails with ample liquidity and its leverage metrics are expected to remain well within the ranges for a strong 'BBB' credit rating.\n\nLooking beyond 2024, over the next several years, Pembina sees the potential for mid-single digit annual volume growth across the WCSB, primarily from the northeast British Columbia (\"NEBC\") Montney formation. Near-term catalysts, including new LNG export capacity, the completion of the TransMountain Pipeline expansion, and Dow's Path2Zero Project are expected to contribute to WCSB production growth.\n\nPembina is uniquely positioned to capture new volumes and benefit from the growth in the WCSB given the scope and reach of its assets, highly economic expansion opportunities, existing long-term contracts, and agreements with three premier NEBC producers. Consistent with our strategy, we will continue to invest in infrastructure to serve customers and enhance Pembina's integrated value chain, while also pursuing opportunities to enhance access to global markets and better align the Company's future with the transition to a lower-carbon economy.\n\nOur investors have come to expect strong and consistent financial leadership from us, demonstrated by a secure and growing dividend, an unwavering commitment to our financial guardrails, a low-risk and primarily fee-based business with high take-or-pay or cost-of-service contributions, and strong balance sheet metrics. Investors can expect us to live up to our reputation and execute our strategy with the same financial discipline that has made Pembina successful to date.\n\nPembina's 2023 Annual Summary, including our messages to shareholders, is available at www.pembina.com/investors/investor-documents-filings.\n\nProjects and New Developments (1)\n\nPipelines\n\nThe Phase VIII Peace Pipeline expansion will enable segregated pipeline service for ethane-plus and propane-plus NGL mix from Gordondale, Alberta, which is centrally located within the Montney trend, into the Edmonton area for market delivery. The project includes new 10-inch and 16-inch pipelines, totaling approximately 150 kilometres, in the Gordondale to La Glace corridor of Alberta, as well as new mid-point pump stations and terminal upgrades located throughout the Peace Pipeline system. Phase VIII will add approximately 235,000 bpd of incremental capacity between Gordondale, Alberta and La Glace, Alberta, as well as approximately 65,000 bpd of capacity between La Glace, Alberta and the Namao hub near Edmonton, Alberta. The estimated project cost has been revised lower to $430 million (previously $475 million; original budget of $530 million). The revised cost reflects highly effective project management and execution, favourable weather conditions and productive contractor relationships. The project is trending on time, with three pump stations completed. The construction is expected to be completed in the first quarter of 2024, with pipeline and facility commissioning and start-up expected in the second quarter of 2024.The NEBC MPS Expansion includes a new mid-point pump station, terminal upgrades, and additional storage, which will support approximately 40,000 bpd of incremental capacity on the NEBC Pipeline system. This expansion is expected to cost $90 million and will fulfill customer demand in light of growing production volumes from NEBC and previously announced long-term midstream service agreements with three premier NEBC Montney producers. The project is trending on time and on budget and is expected to enter service in the fourth quarter of 2024. Additionally, Pembina continues to evaluate further expansions to support volume growth in northeastern British Columbia, including new pipelines and terminal upgrades on the NEBC Pipeline and downstream systems between Taylor, British Columbia and Gordondale, Alberta. In 2023, Pembina filed its project notification with the Canada Energy Regulator in respect of the interprovincial portion of these expansions.\n\nFacilities\n\nPembina is constructing a new 55,000 bpd propane-plus fractionator (\"RFS IV\") at its existing Redwater fractionation and storage complex (the \"Redwater Complex\"). RFS IV is expected to cost approximately $460 million and will leverage the design, engineering and operating best practices of its existing facilities. The project includes additional rail loading capacity at the Redwater Complex. Subject to regulatory and environmental approvals, RFS IV is expected to be in-service in the first half of 2026 and is currently trending on time and on budget. With the addition of RFS IV, the fractionation capacity at the Redwater Complex will total 256,000 bpd. Site clearing activities have been completed, engineering and procurement activities continue, and site construction is expected to begin in the second quarter of 2024.PGI's Wapiti Expansion will increase natural gas processing capacity at the Wapiti Plant by 115 mmcf/d (gross to PGI). The project, which includes a new sales gas pipeline and other related infrastructure, is expected to cost $230 million ($140 million net to Pembina) with an estimated in-service date in the first half of 2026, subject to regulatory and environmental approval.PGI is developing a 28 MW cogeneration facility at its K3 Plant (the \"K3 Cogeneration Facility\"), which is expected to cost $115 million ($70 million net to Pembina). The K3 Cogeneration Facility is expected to reduce overall operating costs by providing power and heat to the gas processing facility, while reducing customers' exposure to power prices. The K3 Cogeneration Facility is expected to fully supply the K3 Plant's power requirements, with excess power sold to the grid at market rates. Further, this project is expected to contribute to a reduction in annual emissions compliance costs at the K3 Plant through the utilization of the cogeneration waste heat and the low-emission power generated and is expected to be in-service in the first half of 2026.\n\nMarketing & New Ventures\n\nCedar LNG has substantially completed several key project deliverables, including obtaining material regulatory approvals; advancing inter-project agreements with Coastal GasLink and LNG Canada; signing a heads of agreement with Samsung Heavy Industries Co., Ltd. and Black & Veatch Corporation; and executing a lump sum engineering, procurement, and construction agreement (the \"EPC Agreement\") to provide Cedar LNG with the necessary services to construct the project. In order to achieve this momentum, as at December 31, 2023, Pembina had invested approximately $200 million in Cedar LNG.\n\nThough numerous milestones have been achieved, the Cedar LNG project still faces a number of schedule driven interconnected elements that require resolution prior to making a final investment decision (\"FID\"), including binding commercial offtake, obtaining certain third-party consents, and project financing. On this basis, a final investment decision is now expected in the middle of 2024.\n\nAs a result of the revised FID timing, current year net contributions to Cedar LNG through to the middle of 2024 are expected to be approximately $200 to $300 million.\n\nFurther, in connection with, and following execution of, the EPC Agreement, Pembina was required to provide financial assurances to advance upstream infrastructure projects. In addition, to further progress the project, Pembina expects to take additional steps which will require providing additional financial assurances. Total financial assurances up to $230 million may be required in 2024, prior to an FID. These financial assurances may become payable in the case of a negative FID. In conjunction with a positive FID, these financial assurances will be transferred to Cedar LNG.Pembina and TC Energy Corporation (\"TC Energy\") have formed a partnership to develop the Alberta Carbon Grid (\"ACG\"), a carbon transportation and sequestration platform. ACG is developing the Industrial Heartland project, which will have the potential to transport and store up to ten million tonnes of carbon dioxide annually. ACG completed the appraisal well drilling, logging and testing in December 2023. Preliminary data was consistent with ACG's storage capacity expectations and further work is underway to confirm the initial results. Throughout 2024, ACG will continue to progress commercial conversations, refine the project scope, and advance project engineering, including facility design and work on the pipeline routing.\n\nFourth Quarter 2023 Conference Call & Webcast\n\nPembina will host a conference call on Friday, February 23, 2024 at 8:00 a.m. MT (10:00 a.m. ET) for interested investors, analysts, brokers and media representatives to discuss results for the fourth quarter of 2023. The conference call dial-in numbers for Canada and the U.S. are 1-416-764-8624 or 1-888-259-6580. A recording of the conference call will be available for replay until Friday, March 1, 2024 at 11:59 p.m. ET. To access the replay, please dial either 1-416-764-8692 or 1-877-674-7070 and enter the password 454444 #.\n\nA live webcast of the conference call can be accessed on Pembina's website at www.pembina.com under Investor Centre/ Presentation & Events, or by entering:\n\nhttps://events.q4inc.com/attendee/659522994 in your web browser. Shortly after the call, an audio archive will be posted on the website for a minimum of 90 days.\n\nAbout Pembina\n\nPembina Pipeline Corporation is a leading energy transportation and midstream service provider that has served North America's energy industry for 70 years. Pembina owns an integrated network of hydrocarbon liquids and natural gas pipelines, gas gathering and processing facilities, oil and natural gas liquids infrastructure and logistics services, and an export terminals business. Through our integrated value chain, we seek to provide safe and reliable energy solutions that connect producers and consumers across the world, support a more sustainable future and benefit our customers, investors, employees and communities. For more information, please visit www.pembina.com.\n\nPurpose of Pembina: We deliver extraordinary energy solutions so the world can thrive.\n\nPembina is structured into three Divisions: Pipelines Division, Facilities Division and Marketing & New Ventures Division.\n\nPembina's common shares trade on the Toronto and New York stock exchanges under PPL and PBA, respectively. For more information, visit www.pembina.com.\n\nForward-Looking Statements and Information\n\nThis news release contains certain forward-looking statements and forward-looking information (collectively, \"forward-looking statements\"), including forward-looking statements within the meaning of the \"safe harbor\" provisions of applicable securities legislation, that are based on Pembina's current expectations, estimates, projections and assumptions in light of its experience and its perception of historical trends. In some cases, forward-looking statements can be identified by terminology such as \"continue\", \"anticipate\", \"will\", \"expects\", \"estimate\", \"potential\", \"planned\", \"future\", \"outlook\", \"strategy\", \"protect\", \"plan\", \"commit\", \"maintain\", \"focus\", \"ongoing\", \"believe\" and similar expressions suggesting future events or future performance.\n\nIn particular, this news release contains forward-looking statements, including certain financial outlooks, pertaining to, without limitation, the following: future pipeline, processing, fractionation and storage facility and system operations and throughput levels; Pembina's strategy and the development of new business initiatives and growth opportunities, including the anticipated benefits therefrom and the expected timing thereof; expectations about industry activities and development opportunities, as well as the anticipated benefits thereof, including operating segment and general market conditions outlooks and industry developments for 2024 and thereafter; expectations about future demand for Pembina's infrastructure and services, including expectations in respect of customer contracts, future volume growth in the WCSB, increased utilization and future tolls and volumes; expectations relating to the development and anticipated benefits of Pembina's new projects and developments, including the Phase VIII Peace Pipeline expansion, Cedar LNG, RFS IV, ACG, the NEBC MPS Expansion, the Wapiti Expansion and the K3 Cogeneration Facility, including the timing thereof; expectations relating to the development and anticipated benefits of the Path2Zero Project, including the timing thereof; the Alliance/Aux Sable Acquisition, including the timing and anticipated benefits thereof; Pembina's previously announced 2024 adjusted EBITDA guidance range, and future revisions thereto; Pembina's future common share dividends, including the timing, amount and expected tax treatment thereof; planning, construction, locations, capital expenditure estimates, schedules, regulatory and environmental applications and anticipated approvals, expected capacity, incremental volumes, contractual arrangements, completion and in-service dates, rights, sources of product, activities, benefits and operations with respect to new construction of, repairs to or expansions on existing pipelines, systems, gas services facilities, processing and fractionation facilities, terminalling, storage and hub facilities and other facilities or energy infrastructure, as well as the impact of Pembina's new projects on its future financial performance and stakeholders; expectations regarding Pembina's financial strength and condition; expectations regarding Pembina's commercial agreements, including the expected timing and benefit thereof; statements and expectations related to Pembina's commitment to, and the effectiveness and impact of, its sustainability goals and targets; and the impact of current and expected market conditions on Pembina.\n\nThe forward-looking statements are based on certain factors and assumptions that Pembina has made in respect thereof as at the date of this news release regarding, among other things: oil and gas industry exploration and development activity levels and the geographic region of such activity; the success of Pembina's operations; prevailing commodity prices, interest rates, carbon prices, tax rates, exchange rates and inflation rates; the ability of Pembina to maintain current credit ratings; the availability and cost of capital to fund future capital requirements relating to existing assets, projects and the repayment or refinancing of existing debt as it becomes due; future operating costs; geotechnical and integrity costs; that any third-party projects relating to Pembina's growth projects will be sanctioned and completed as expected; the satisfaction of the conditions to closing of the Alliance/Aux Sable Acquisition in a timely manner, including receipt of all necessary approvals; that the Alliance/Aux Sable Acquisition will be completed on terms consistent with management's current expectations; assumptions with respect to our intention to complete share repurchases, including the funding thereof, existing and future market conditions, including with respect to Pembina's common share trading price, and compliance with respect to applicable securities laws and regulations and stock exchange policies; that any required commercial agreements can be reached in the manner and on the terms expected by Pembina; that all required regulatory and environmental approvals can be obtained on the necessary terms and in a timely manner; that counterparties will comply with contracts in a timely manner; that there are no unforeseen events preventing the performance of contracts or the completion of the relevant projects; prevailing regulatory, tax and environmental laws and regulations; maintenance of operating margins; the amount of future liabilities relating to lawsuits and environmental incidents; and the availability of coverage under Pembina's insurance policies (including in respect of Pembina's business interruption insurance policy).\n\nAlthough Pembina believes the expectations and material factors and assumptions reflected in these forward-looking statements are reasonable as of the date hereof, there can be no assurance that these expectations, factors and assumptions will prove to be correct. These forward-looking statements are not guarantees of future performance and are subject to a number of known and unknown risks and uncertainties including, but not limited to: the regulatory environment and decisions and Indigenous and landowner consultation requirements; the impact of competitive entities and pricing; reliance on third parties to successfully operate and maintain certain assets; reliance on key relationships, joint venture partners and agreements; labour and material shortages; the strength and operations of the oil and natural gas production industry and related commodity prices; non-performance or default by counterparties to agreements which Pembina or one or more of its affiliates has entered into in respect of its business; actions by governmental or regulatory authorities, including changes in tax laws and treatment, changes in royalty rates, changes in regulatory processes or increased environmental regulation; the ability of Pembina to acquire or develop the necessary infrastructure in respect of future development projects; the ability of Pembina and Enbridge to receive all necessary regulatory approvals and satisfy all other necessary conditions to closing of the Alliance/Aux Sable Acquisition on a timely basis or at all; Pembina's ability to realize the anticipated benefits of the Alliance/Aux Sable Acquisition; fluctuations in operating results; adverse general economic and market conditions, including potential recessions in Canada, North America and worldwide resulting in changes, or prolonged weaknesses, as applicable, in interest rates, foreign currency exchange rates, inflation rates, commodity prices, supply/demand trends and overall industry activity levels; constraints on the, or the unavailability of, adequate supplies, infrastructure or labour; the political environment in North American and elsewhere, and public opinion; the ability to access various sources of debt and equity capital; adverse changes in credit ratings; counterparty credit risk; technology and cyber security risks; natural catastrophes; and certain other risks detailed in Pembina's Annual Information Form and Management's Discussion and Analysis, each dated February 22, 2024 for the year ended December 31, 2023 and from time to time in Pembina's public disclosure documents available atwww.sedarplus.ca,www.sec.govand through Pembina's website atwww.pembina.com.\n\nThis list of risk factors should not be construed as exhaustive. Readers are cautioned that events or circumstances could cause results to differ materially from those predicted, forecasted or projected by forward-looking statements contained herein. The forward-looking statements contained in this news release speak only as of the date of this news release. Pembina does not undertake any obligation to publicly update or revise any forward-looking statements or information contained herein, except as required by applicable laws. Management approved the 2024 adjusted EBITDA guidance contained herein on December 11, 2023. The purpose of the 2024 adjusted EBITDA guidance is to assist readers in understanding Pembina's expected and targeted financial results, and this information may not be appropriate for other purposes. The forward-looking statements contained in this news release are expressly qualified by this cautionary statement.\n\nNon-GAAP and Other Financial Measures\n\nThroughout this news release, Pembina has disclosed certain financial measures and ratios that are not specified, defined or determined in accordance with GAAP and which are not disclosed in Pembina's financial statements. Non-GAAP financial measures either exclude an amount that is included in, or include an amount that is excluded from, the composition of the most directly comparable financial measure specified, defined and determined in accordance with GAAP. Non-GAAP ratios are financial measures that are in the form of a ratio, fraction, percentage or similar representation that has a non-GAAP financial measure as one or more of its components. These non-GAAP financial measures and non-GAAP ratios, together with financial measures and ratios specified, defined and determined in accordance with GAAP, are used by management to evaluate the performance and cash flows of Pembina and its businesses and to provide additional useful information respecting Pembina's financial performance and cash flows to investors and analysts.\n\nIn this news release, Pembina has disclosed the following non-GAAP financial measures and non-GAAP ratios: net revenue, adjusted EBITDA, adjusted EBITDA from equity accounted investees, adjusted EBITDA per common share, adjusted cash flow from operating activities, adjusted cash flow from operating activities per common share, and proportionately consolidated debt-to-adjusted EBITDA. The non-GAAP financial measures and non-GAAP ratios disclosed in this news release do not have any standardized meaning under International Financial Reporting Standards (\"IFRS\") and may not be comparable to similar financial measures or ratios disclosed by other issuers. Such financial measures and ratios should not, therefore, be considered in isolation or as a substitute for, or superior to, measures and ratios of Pembina's financial performance, or cash flows specified, defined or determined in accordance with IFRS, including revenue, earnings, cash flow from operating activities and cash flow from operating activities per share.\n\nExcept as otherwise described herein, these non-GAAP financial measures and non-GAAP ratios are calculated on a consistent basis from period to period. Specific reconciling items may only be relevant in certain periods.\n\nBelow is a description of each non-GAAP financial measure and non-GAAP ratio disclosed in this news release, together with, as applicable, disclosure of the most directly comparable financial measure that is determined in accordance with GAAP to which each non-GAAP financial measure relates and a quantitative reconciliation of each non-GAAP financial measure to such directly comparable GAAP financial measure. Additional information relating to such non-GAAP financial measures and non-GAAP ratios, including disclosure of the composition of each non-GAAP financial measure and non-GAAP ratio, an explanation of how each non-GAAP financial measure and non-GAAP ratio provides useful information to investors and the additional purposes, if any, for which management uses each non-GAAP financial measure and non-GAAP ratio; an explanation of the reason for any change in the label or composition of each non-GAAP financial measure and non-GAAP ratio from what was previously disclosed; and a description of any significant difference between forward-looking non-GAAP financial measures and the equivalent historical non-GAAP financial measures, is contained in the \"Non-GAAP & Other Financial Measures\" section of the management's discussion and analysis of Pembina dated February 22, 2024 for the year ended December 31, 2023 (the \"MD&A\"), which information is incorporated by reference in this news release. The MD&A is available on SEDAR+ atwww.sedarplus.ca, EDGAR atwww.sec.govand Pembina's website atwww.pembina.com.\n\nNet Revenue\n\nNet revenue is a non-GAAP financial measure which is defined as total revenue less cost of goods sold including product purchases. The most directly comparable financial measure to net revenue that is determined in accordance with GAAP and disclosed in Pembina's financial statements is revenue.\n\n3 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nCorporate &\n\nInter-segment Eliminations\n\nTotal\n\n($ millions)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nRevenue\n\n737\n\n686\n\n248\n\n237\n\n1,660\n\n1,921\n\n(179)\n\n(145)\n\n2,466\n\n2,699\n\nCost of goods sold, including product purchases\n\n11\n\n--\n\n--\n\n--\n\n1,476\n\n1,734\n\n(138)\n\n(78)\n\n1,349\n\n1,656\n\nNet revenue\n\n726\n\n686\n\n248\n\n237\n\n184\n\n187\n\n(41)\n\n(67)\n\n1,117\n\n1,043\n\n12 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nCorporate &\n\nInter-segment Eliminations\n\nTotal\n\n($ millions)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nRevenue\n\n2,707\n\n2,508\n\n909\n\n1,268\n\n6,087\n\n8,471\n\n(578)\n\n(636)\n\n9,125\n\n11,611\n\nCost of goods sold, including product purchases\n\n17\n\n--\n\n--\n\n6\n\n5,509\n\n7,682\n\n(395)\n\n(324)\n\n5,131\n\n7,364\n\nNet revenue\n\n2,690\n\n2,508\n\n909\n\n1,262\n\n578\n\n789\n\n(183)\n\n(312)\n\n3,994\n\n4,247\n\nAdjusted Earnings Before Interest, Taxes, Depreciation and Amortization\n\nAdjusted EBITDA is a non-GAAP financial measure and is calculated as earnings before net finance costs, income taxes, depreciation and amortization (included in operations and general and administrative expense) and unrealized gains or losses on commodity-related derivative financial instruments. The exclusion of unrealized gains or losses on commodity-related derivative financial instruments eliminates the non-cash impact of such gains or losses.\n\nAdjusted EBITDA also includes adjustments to earnings for losses (gains) on disposal of assets, transaction costs incurred in respect of acquisitions, dispositions and restructuring, impairment charges or reversals in respect of goodwill, intangible assets, investments in equity accounted investees and property, plant and equipment, certain non-cash provisions and other amounts not reflective of ongoing operations. These additional adjustments are made to exclude various non-cash and other items that are not reflective of ongoing operations.\n\nThe equivalent historical non-GAAP financial measure to 2024 adjusted EBITDA guidance is adjusted EBITDA for the year ended December 31, 2023.\n\nAdjusted EBITDA per common share is a non-GAAP ratio which is calculated by dividing adjusted EBITDA by the weighted average number of common shares outstanding.\n\n3 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nCorporate &\n\nInter-segment Eliminations\n\nTotal\n\n($ millions, except per share amounts)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nEarnings (loss) before income tax\n\n677\n\n295\n\n143\n\n145\n\n204\n\n96\n\n(209)\n\n(206)\n\n815\n\n330\n\nAdjustments to share of profit from equity accounted investees and other\n\n45\n\n41\n\n135\n\n107\n\n6\n\n--\n\n--\n\n--\n\n186\n\n148\n\nNet finance cost\n\n6\n\n6\n\n3\n\n(8)\n\n(4)\n\n6\n\n111\n\n109\n\n116\n\n113\n\nDepreciation and amortization\n\n109\n\n104\n\n46\n\n34\n\n12\n\n10\n\n11\n\n14\n\n178\n\n162\n\nUnrealized (gain) loss on commodity-related derivative financial instruments\n\n--\n\n--\n\n--\n\n(2)\n\n(46)\n\n61\n\n--\n\n--\n\n(46)\n\n59\n\nImpairment reversal\n\n(231)\n\n--\n\n--\n\n--\n\n--\n\n--\n\n--\n\n--\n\n(231)\n\n--\n\nGain on disposal of assets, transaction costs incurred in respect of acquisitions and non-cash provisions\n\n11\n\n102\n\n(3)\n\n12\n\n1\n\n(2)\n\n6\n\n1\n\n15\n\n113\n\nAdjusted EBITDA\n\n617\n\n548\n\n324\n\n288\n\n173\n\n171\n\n(81)\n\n(82)\n\n1,033\n\n925\n\nAdjusted EBITDA per common share - basic (dollars)\n\n1.87\n\n1.68\n\n12 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nCorporate &\n\nInter-segment Eliminations\n\nTotal\n\n($ millions, except per share amounts)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nEarnings (loss) before income tax\n\n1,840\n\n1,415\n\n610\n\n1,804\n\n435\n\n708\n\n(696)\n\n(708)\n\n2,189\n\n3,219\n\nAdjustments to share of profit from equity accounted investees and other\n\n172\n\n172\n\n438\n\n271\n\n84\n\n25\n\n--\n\n--\n\n694\n\n468\n\nNet finance costs\n\n28\n\n28\n\n9\n\n13\n\n4\n\n27\n\n425\n\n418\n\n466\n\n486\n\nDepreciation and amortization\n\n414\n\n396\n\n159\n\n196\n\n46\n\n44\n\n44\n\n47\n\n663\n\n683\n\nUnrealized loss (gain) on commodity-related derivative financial instruments\n\n--\n\n--\n\n--\n\n(50)\n\n32\n\n(83)\n\n--\n\n--\n\n32\n\n(133)\n\nGain on PGI Transaction\n\n--\n\n--\n\n--\n\n(1,110)\n\n--\n\n--\n\n--\n\n--\n\n--\n\n(1,110)\n\nImpairment reversal\n\n(231)\n\n--\n\n--\n\n--\n\n--\n\n--\n\n--\n\n--\n\n(231)\n\n--\n\nTransaction costs incurred in respect of acquisitions, transformation and restructuring costs, contract dispute settlement, gain on disposal of assets and non-cash provisions\n\n11\n\n116\n\n(3)\n\n13\n\n(4)\n\n--\n\n7\n\n4\n\n11\n\n133\n\nAdjusted EBITDA\n\n2,234\n\n2,127\n\n1,213\n\n1,137\n\n597\n\n721\n\n(220)\n\n(239)\n\n3,824\n\n3,746\n\nAdjusted EBITDA per common share - basic (dollars)\n\n6.95\n\n6.78\n\nAdjusted EBITDA from Equity Accounted Investees\n\nIn accordance with IFRS, Pembina's jointly controlled investments are accounted for using equity accounting. Under equity accounting, the assets and liabilities of the investment are presented net in a single line item in the Consolidated Statement of Financial Position, \"Investments in Equity Accounted Investees\". Net earnings from investments in equity accounted investees are recognized in a single line item in the Consolidated Statement of Earnings and Comprehensive Income \"Share of Profit from Equity Accounted Investees\". The adjustments made to earnings, in adjusted EBITDA above, are also made to share of profit from investments in equity accounted investees. Cash contributions and distributions from investments in equity accounted investees represent Pembina's share paid and received in the period to and from the investments in equity accounted investees.\n\nTo assist in understanding and evaluating the performance of these investments, Pembina is supplementing the IFRS disclosure with non-GAAP proportionate consolidation of Pembina's interest in the investments in equity accounted investees. Pembina's proportionate interest in equity accounted investees has been included in adjusted EBITDA.\n\n3 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nTotal\n\n($ millions)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nShare of profit (loss) from equity accounted investees\n\n31\n\n44\n\n48\n\n49\n\n15\n\n(14)\n\n94\n\n79\n\nAdjustments to share of profit from equity accounted investees:\n\nNet finance costs (income)\n\n7\n\n5\n\n84\n\n37\n\n--\n\n(1)\n\n91\n\n41\n\nIncome tax (recovery) expense\n\n--\n\n--\n\n(13)\n\n13\n\n--\n\n--\n\n(13)\n\n13\n\nDepreciation and amortization\n\n38\n\n36\n\n60\n\n39\n\n6\n\n7\n\n104\n\n82\n\nUnrealized loss (gain) on commodity-related derivative financial instruments\n\n--\n\n--\n\n7\n\n11\n\n--\n\n(6)\n\n7\n\n5\n\nTransaction costs incurred in respect of acquisitions and non-cash provisions\n\n--\n\n--\n\n(3)\n\n7\n\n--\n\n--\n\n(3)\n\n7\n\nTotal adjustments to share of profit from equity accounted investees\n\n45\n\n41\n\n135\n\n107\n\n6\n\n--\n\n186\n\n148\n\nAdjusted EBITDA from equity accounted investees\n\n76\n\n85\n\n183\n\n156\n\n21\n\n(14)\n\n280\n\n227\n\n12 Months Ended December 31\n\nPipelines\n\nFacilities\n\nMarketing &\n\nNew Ventures\n\nTotal\n\n($ millions)\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\n2023\n\n2022\n\nShare of profit (loss) from equity accounted investees\n\n109\n\n171\n\n233\n\n108\n\n(26)\n\n82\n\n316\n\n361\n\nAdjustments to share of profit from equity accounted investees:\n\nNet finance costs\n\n22\n\n23\n\n160\n\n79\n\n1\n\n--\n\n183\n\n102\n\nIncome tax expense\n\n--\n\n--\n\n41\n\n14\n\n--\n\n--\n\n41\n\n14\n\nDepreciation and amortization\n\n150\n\n149\n\n207\n\n138\n\n25\n\n25\n\n382\n\n312\n\nUnrealized loss on commodity-related derivative financial instruments\n\n--\n\n--\n\n16\n\n27\n\n--\n\n--\n\n16\n\n27\n\nTransaction costs incurred in respect of acquisitions and non-cash provisions\n\n--\n\n--\n\n14\n\n13\n\n58\n\n--\n\n72\n\n13\n\nTotal adjustments to share of profit from equity accounted investees\n\n172\n\n172\n\n438\n\n271\n\n84\n\n25\n\n694\n\n468\n\nAdjusted EBITDA from equity accounted investees\n\n281\n\n343\n\n671\n\n379\n\n58\n\n107\n\n1,010\n\n829\n\nAdjusted Cash Flow from Operating Activities and Adjusted Cash Flow from Operating Activities per Common Share\n\nAdjusted cash flow from operating activities is a non-GAAP financial measure which is defined as cash flow from operating activities adjusting for the change in non-cash operating working capital, adjusting for current tax and share-based compensation payment, and deducting preferred share dividends paid. Adjusted cash flow from operating activities deducts preferred share dividends paid because they are not attributable to common shareholders. The calculation has been modified to include current tax and share-based compensation payment as it allows management to better assess the obligations discussed below.\n\nManagement believes that adjusted cash flow from operating activities provides comparable information to investors for assessing financial performance during each reporting period. Management utilizes adjusted cash flow from operating activities to set objectives and as a key performance indicator of the Company's ability to meet interest obligations, dividend payments and other commitments.\n\nAdjusted cash flow from operating activities per common share is a non-GAAP ratio which is calculated by dividing adjusted cash flow from operating activities by the weighted average number of common shares outstanding.\n\n3 Months Ended\n\nDecember 31\n\n12 Months Ended December 31\n\n($ millions, except per share amounts)\n\n2023\n\n2022\n\n2023\n\n2022\n\nCash flow from operating activities\n\n880\n\n947\n\n2,635\n\n2,929\n\nCash flow from operating activities per common share - basic (dollars)\n\n1.60\n\n1.72\n\n4.79\n\n5.30\n\nAdd (deduct):\n\nChange in non-cash operating working capital\n\n(54)\n\n(220)\n\n210\n\n(177)\n\nCurrent tax expense\n\n(54)\n\n18\n\n(325)\n\n(227)\n\nTaxes paid, net of foreign exchange\n\n49\n\n28\n\n236\n\n334\n\nAccrued share-based payment expense\n\n(44)\n\n(51)\n\n(67)\n\n(117)\n\nShare-based compensation payment\n\n--\n\n--\n\n77\n\n45\n\nPreferred share dividends paid\n\n(30)\n\n(32)\n\n(120)\n\n(126)\n\nAdjusted cash flow from operating activities\n\n747\n\n690\n\n2,646\n\n2,661\n\nAdjusted cash flow from operating activities per common share - basic (dollars)\n\n1.36\n\n1.25\n\n4.81\n\n4.82\n\nProportionately Consolidated Debt-to-Adjusted EBITDA\n\nProportionately Consolidated Debt-to-Adjusted EBITDA is a non-GAAP ratio that management believes is useful to investors and other users of Pembina's financial information in the evaluation of the Company's debt levels and creditworthiness.\n\nAs at December 31\n\n($ millions, except as noted)\n\n2023\n\n2022\n\nLoans and borrowings (current)\n\n650\n\n600\n\nLoans and borrowings (non-current)\n\n9,253\n\n9,405\n\nLoans and borrowings of equity accounted investees\n\n2,805\n\n3,366\n\nProportionately consolidated debt\n\n12,708\n\n13,371\n\nAdjusted EBITDA\n\n3,824\n\n3,746\n\nProportionately consolidated debt-to-adjusted EBITDA (times)\n\n3.3\n\n3.6\n\nView source version on businesswire.com:https://www.businesswire.com/news/home/20240222955162/en/\n\nCONTACT: Investor Relations\n\n(403) 231-3156\n\n1-855-880-7404\n\ne-mail:investor-relations@pembina.com\n\nwww.pembina.com\n\nKEYWORD: UNITED STATES NORTH AMERICA CANADA\n\nINDUSTRY KEYWORD: ENERGY OTHER ENERGY UTILITIES OIL/GAS\n\nSOURCE: Pembina Pipeline Corporation\n\nCopyright Business Wire 2024.\n\nPUB: 02/22/2024 06:11 PM/DISC: 02/22/2024 06:10 PM\n\nhttp://www.businesswire.com/news/home/20240222955162/en",
        "The industrial sector is well-positioned for robust growth and expansion, propelled by consumer demand for industrial products and services, infrastructure development, government backing, and technological advances. Thus, quality industrial stocks Siemens Aktiengesellschaft (SIEGY), AptarGroup (ATR), and Amada Co. (AMDLY) could be ideal buys for potential gains. Read more....\n\nThe industrial sector, which includes manufacturing, construction, and more, has a solid footing, with several factors such as technological innovation, sustained consumer demand for industrial products and services, growing investments in infrastructure, and favorable government funding and policies, attributing to the sector's growth.\n\nGiven the industry's tailwinds, it could be wise to invest in fundamentally sound industrial stocks Siemens Aktiengesellschaft (SIEGY), AptarGroup, Inc. (ATR), and Amada Co. Ltd. (AMDLY) for substantial returns.\n\nDespite labor shortages and continued supply chain disruptions, the manufacturing industry stands sturdy and will continue to witness significant growth in the foreseeable future. Production of industrial goods, including aircraft, automobiles, chemicals, consumer electronics, heavy machinery, oil, and steel, is exceeding pre-pandemic levels.\n\nWith the rapid expansion of the manufacturing sector, the industrial machinery industry is poised for significant profitability in the upcoming years. Further, the industry's prospects are driven by the demand for automation and the modernization of the production process. The industrial machinery market is estimated to reach $777.35 billion in 2028, growing at a CAGR of 7.2%.\n\nThe industrial packaging market is also picking pace with the increasing volume of resources and products being transported across various regions. Amid the rigid plastic regulations, more and more companies are engaging and launching new and innovative products in line with the changing demand for sustainable and recyclable industrial packaging.\n\nThe industrial packaging market is expected to be valued at $66.27 billion in 2024. The market is further anticipated to grow at a CAGR of 4.7% during the forecast period (2024-2029), resulting in a market volume of $83.45 billion by 2029.\n\nSupportive government funding & policies and numerous technological advancements will further shape industrial manufacturing trends this year and beyond.\n\nGovernment initiatives, such as the CHIPS and Science Act, which allocates $50 billion for the domestic semiconductor industry, and the Infrastructure Investment and Jobs Act (IIJA), which sets aside $1.2 trillion for transportation and infrastructure, are creating new avenues for the industry players.\n\nThe manufacturing sector is notably making a transformative shift from machine-based assembly lines to \"smart factories,\" using AI, the Internet of Things (IoT), robotics, data analytics, and other advanced technologies. The movement, known as Industry 4.0, is the next stage of the digitalization of manufacturing, fueled by advances in automation and connectivity.\n\nInvestor's interest in industrial stocks is evident from the Industrial Select Sector SPDR Fund's (XLI) 10.4% returns over the past six months.\n\nGiven the industry's solid growth prospects, investing in fundamentally strong industrial stocks SIEGY, ATR, and AMDLY could be wise for future gains.\n\nLet's discuss the fundamentals of these stocks in detail:\n\nSiemens Aktiengesellschaft (SIEGY)\n\nHeadquartered in Munich, Germany, SIEGY is a leading technology company that emphasizes automation and digitalization worldwide. The company operates through Digital Industries; Smart Infrastructure; Mobility; Siemens Healthineers; and Siemens Financial Services (SFS) segments.\n\nOn February 15, 2024, SIEGY supplied 200 VersiCharge wallboxes and an intelligent charging management system to the Portuguese Infinity building, one of the tallest residential sites in Lisbon, Portugal. The contract includes delivery of SICAM Dynamic Load Management, a solution by SIEGY to use grid capacity efficiently.\n\nWith this deal, SIEGY is preparing one of Portugal's tallest buildings for the future of eMobility. The integrated EV (Electric Vehicle) charging solution customized by SIEGY's engineering and software teams in Portugal allows for dynamic and intelligent on-site charging management.\n\nOn February 6, SIEGY and Italian distribution system operator (DSO), Areti announced their collaboration on the RomeFlex project to test the ability to manage congestion and voltage volatility across the stressed power grids of Italy's capital city. Areti will use SIEGY's technology to forecast grid congestion and request flexibility on MV and LV grids.\n\nWith SIEGY's expertise and software, Areti is managing challenges related to climate change and \"the electrification of everything,' heavily impacting power grids in Italy and all around the world.\n\nAlso, on February 5, SIEGY announced the release of a new generative artificial intelligence (AI) functionality into its predictive maintenance solution - Senseye Predictive Maintenance. The new generative AI functionality makes predictive maintenance more conversational and intuitive.\n\nWith the new release, SIEGY will make human-machine interactions and predictive maintenance more efficient and faster by enhancing proven machine learning capabilities with generative AI.\n\nFor the fiscal 2024 first quarter that ended December 31, 2023, SIEGY's revenue grew 1.9% year-over-year to €18.41 billion ($19.84 billion). The company's gross profit rose 3.1% year-over-year to €7.18 billion ($7.74 billion). Its income from continuing operations came in at €2.53 billion ($2.73 billion), up 54.2% from the prior year's quarter.\n\nIn addition, SIEGY's net income for the quarter amounted to €2.55 billion ($2.74 billion), or €2.99 per share, a 55.7% and 61.6% growth from the previous year's quarter, respectively. Its free cash flow from continued and discontinued operations was €1.05 billion ($1.13 billion), an increase of 1,118.6% year-over-year.\n\nStreet expects SIEGY's revenue for the third quarter (ending June 2024) to increase 3.9% year-over-year to $21.55 billion. The company's EPS for the same quarter is expected to grow 38.5% year-over-year to $1.26. Moreover, the company topped the consensus EPS estimates in three of the trailing four quarters, which is impressive.\n\nShares of SIEGY have surged 21.6% over the past six months and 15.5% over the past year to close the last trading session at $90.71.\n\nSIEGY's solid fundamentals are reflected in its POWR Ratings. The stock has an overall rating of B, which translates to a Buy in our proprietary rating system. The POWR Ratings are calculated by considering 118 different factors, each weighted to an optimal degree.\n\nSIEGY has a B grade for Value, Growth, and Stability. It is ranked #3 out of 35 stocks in the B-rated Industrial - Manufacturing industry.\n\nIn addition to the POWR Ratings we've stated above, we also have SIEGY ratings for Momentum, Sentiment, and Quality. Get all SIEGY ratings here.\n\nAptarGroup, Inc. (ATR)\n\nATR designs and manufactures a variety of drug delivery, consumer product dispensing, and active material science solutions and services for markets, including pharmaceutical, beauty, personal care, home care, and food and beverage. It operates through Aptar Pharma; Aptar Beauty; and Aptar Closures segments.\n\nOn February 9, 2024, ATR's Aptar Digital Health and Biogen Inc. (BIIB) entered into an enterprise agreement to operate and develop digital health solutions for neurological and rare diseases. Under the agreement, Biogen will transfer ownership of select digital health solutions to Aptar Digital Health.\n\nThe new partnership model leverages Aptar Digital Health's capabilities to assist in the development and operation of new and existing digital health solutions globally. The initial scope of the multi-year agreement covers various indications in neurology and immunology across 15 countries.\n\nOn January 19, ATR declared a quarterly cash dividend of $0.41 per share. The payment date for the dividend is February 22, 2024, to stockholders of record as of February 1, 2024.\n\nATR pays an annual dividend of $1.64, which translates to a yield of 1.19% at the current share price. Its four-year average dividend yield is 1.27%. Moreover, the company's dividend payouts have increased at a CAGR of 3.8% over the past three years. Aptar has raised its dividends for 30 consecutive years.\n\nDuring the fourth quarter that ended December 31, 2023, ATR's net sales increased 5.3% year-over-year to $838.48 million. Adjusted net income attributable to ATR rose 28.6% and 27.4% from the prior year's quarter to $81.45 million and $1.21 per share, respectively. Its adjusted EBITDA was $179.45 million, up 22.3% year-over-year.\n\nIn addition, the company's free cash flow came in at $138.49 million, an increase of 40.3% from the previous year's period.\n\nAnalysts expect ATR's revenue and EPS for the first quarter (ending March 2024) to increase 3.9% and 20.8% year-over-year to $893.45 million and $1.15, respectively. Furthermore, the company has surpassed the consensus EPS estimates in each of the trailing four quarters.\n\nATR's stock has gained 13.1% over the past six months and 24.2% over the past year to close the last trading session at $137.50.\n\nATR's bright prospects are reflected in its POWR Ratings. The stock has an overall rating of B, equating to a Buy in our proprietary rating system.\n\nThe stock has a B grade for Growth, Quality, Stability, and Sentiment. ATR is ranked #4 among 19 stocks in the B-rated Industrial - Packaging industry.\n\nBased in Isehara, Japan, AMDLY manufactures, sells, leases, repairs, maintains, checks, and inspects metalworking machinery, software, and peripheral equipment in Japan, North America, Europe, Asia, and internationally. The company offers sheet metal fabrication machines, including laser machines and punch & laser combination machines.\n\nOn October 4, 2023, AMDLY announced the three-dimensional laser integrated system, \"ALCIS-1008e,\" at Photonix 2023. The ALCIS (Advanced Laser Cube Integrated System) is a three-dimensional laser integrated system that can perform various types of laser machining like cutting, welding, and layered manufacturing, all in one machine.\n\nWith the new system, AMDLY can support the high-speed and high-quality processing of highly reflective materials such as copper, for which demand is increasing. The system provides high-precision laser machining to meet the needs of highly variable manufacturing.\n\nOn September 5, AMDLY commenced the sales of its new products in the HRB series of next-generation large press brakes. These machines expand the range of possible processing by enabling the bending and deep bending of thick sheet metal and large items.\n\nThe new HRB series products expand the large-scale machine range to seven models, with support for long and med-to-thick material from 350 tons/3 meters to 600 tons/7 meters. It enables support for steel material processing and also considers environmental concerns.\n\nIn the nine months that ended December 31, 2023, AMDLY's sales revenue increased 10.2% year-over-year to ¥285.22 billion ($1.90 billion), while its gross profit rose 10.9% from the prior year's period to ¥125.90 billion ($838.18 million). Its operating profit came in at ¥40.25 billion ($268 million), up 15% year-over-year.\n\nFurthermore, the company's net income and earnings per share amounted to ¥28.01 billion ($186.48 million) and ¥81.51, indicating increases of 16.5% and 17.9% year-over-year, respectively.\n\nAs per the company's updated guidance for the fiscal year 2023, AMDLY's sales revenue is expected to be ¥395 billion ($2.63 billion). The company expects gross profit of ¥175 billion ($1.16 billion) and net income of ¥39 billion ($259.64 million).\n\nStreet expects AMDLY's revenue for the fiscal year (ending March 2024) to increase 96.7% year-over-year to $2.66 billion. In addition, the company has surpassed the consensus revenue estimates in three of the trailing four quarters.\n\nOver the past six months, the stock has gained 17.8% to close the last trading session at $40.51.\n\nAMDLY's POWR Ratings reflect its promising outlook. The stock has an overall rating of A, which translates to a Strong Buy in our proprietary rating system.\n\nThe stock has an A grade for Value and a B for Quality and Stability. Within the A-rated Industrial - Machinery industry, AMDLY has topped the list of 80 stocks.\n\nClick here to access additional ratings of AMDLY for Growth, Momentum, and Sentiment.\n\nWhat To Do Next?\n\n43 year investment veteran, Steve Reitmeister, has just released his 2024 market outlook along with trading plan and top 11 picks for the year ahead.\n\n2024 Stock Market Outlook >\n\nSIEGY shares were unchanged in premarket trading Monday. Year-to-date, SIEGY has declined -1.02%, versus a 5.09% rise in the benchmark S&P 500 index during the same period.\n\nMangeet's keen interest in the stock market led her to become an investment researcher and financial journalist. Using her fundamental approach to analyzing stocks, Mangeet's looks to help retail investors understand the underlying factors before making investment decisions.",
        "University of Melbourne provides funding as a founding partner of The Conversation AU.\n\nJust over a week ago, European physicists announced they had measured the strength of gravity on the smallest scale ever.\n\nIn a clever tabletop experiment, researchers at Leiden University in the Netherlands, the University of Southampton in the UK, and the Institute for Photonics and Nanotechnologies in Italy measured a force of around 30 attonewtons on a particle with just under half a milligram of mass. An attonewton is a billionth of a billionth of a newton, the standard unit of force.\n\nThe researchers say the work could \"unlock more secrets about the universe's very fabric\" and may be an important step toward the next big revolution in physics.\n\nBut why is that? It's not just the result: it's the method, and what it says about a path forward for a branch of science critics say may be trapped in a loop of rising costs and diminishing returns.\n\nGravity\n\nFrom a physicist's point of view, gravity is an extremely weak force. This might seem like an odd thing to say. It doesn't feel weak when you're trying to get out of bed in the morning!\n\nStill, compared with the other forces that we know about - such as the electromagnetic force that is responsible for binding atoms together and for generating light, and the strong nuclear force that binds the cores of atoms - gravity exerts a relatively weak attraction between objects.\n\nRead more: Explainer: Standard Model of Particle Physics\n\nAnd on smaller scales, the effects of gravity get weaker and weaker.\n\nIt's easy to see the effects of gravity for objects the size of a star or planet, but it is much harder to detect gravitational effects for small, light objects.\n\nThe need to test gravity\n\nDespite the difficulty, physicists really want to test gravity at small scales. This is because it could help resolve a century-old mystery in current physics.\n\nPhysics is dominated by two extremely successful theories.\n\nThe first is general relativity, which describes gravity and spacetime at large scales. The second is quantum mechanics, which is a theory of particles and fields - the basic building blocks of matter - at small scales.\n\nRead more: Approaching zero: super-chilled mirrors edge towards the borders of gravity and quantum physics\n\nThese two theories are in some ways contradictory, and physicists don't understand what happens in situations where both should apply. One goal of modern physics is to combine general relativity and quantum mechanics into a theory of \"quantum gravity\".\n\nOne example of a situation where quantum gravity is needed is to fully understand black holes. These are predicted by general relativity - and we have observed huge ones in space - but tiny black holes may also arise at the quantum scale.\n\nAt present, however, we don't know how to bring general relativity and quantum mechanics together to give an account of how gravity, and thus black holes, work in the quantum realm.\n\nNew theories and new data\n\nA number of approaches to a potential theory of quantum gravity have been developed, including string theory, loop quantum gravity and causal set theory.\n\nHowever, these approaches are entirely theoretical. We currently don't have any way to test them via experiments.\n\nTo empirically test these theories, we'd need a way to measure gravity at very small scales where quantum effects dominate.\n\nUntil recently, performing such tests was out of reach. It seemed we would need very large pieces of equipment: even bigger than the world's largest particle accelerator, the Large Hadron Collider, which sends high-energy particles zooming around a 27-kilometre loop before smashing them together.\n\nTabletop experiments\n\nThis is why the recent small-scale measurement of gravity is so important.\n\nThe experiment conducted jointly between the Netherlands and the UK is a \"tabletop\" experiment. It didn't require massive machinery.\n\nThe experiment works by floating a particle in a magnetic field and then swinging a weight past it to see how it \"wiggles\" in response.\n\nThis is analogous to the way one planet \"wiggles\" when it swings past another.\n\nBy levitating the particle with magnets, it can be isolated from many of the influences that make detecting weak gravitational influences so hard.\n\nThe beauty of tabletop experiments like this is they don't cost billions of dollars, which removes one of the main barriers to conducting small-scale gravity experiments, and potentially to making progress in physics. (The latest proposal for a bigger successor to the Large Hadron Collider would cost US$17 billion.)\n\nWork to do\n\nTabletop experiments are very promising, but there is still work to do.\n\nThe recent experiment comes close to the quantum domain, but doesn't quite get there. The masses and forces involved will need to be even smaller, to find out how gravity acts at this scale.\n\nWe also need to be prepared for the possibility that it may not be possible to push tabletop experiments this far.\n\nThere may yet be some technological limitation that prevents us from conducting experiments of gravity at quantum scales, pushing us back toward building bigger colliders.\n\nBack to the theories\n\nIt's also worth noting some of the theories of quantum gravity that might be tested using tabletop experiments are very radical.\n\nSome theories, such as loop quantum gravity, suggest space and time may disappear at very small scales or high energies. If that's right, it may not be possible to carry out experiments at these scales.\n\nRead more: Explainer: String theory\n\nAfter all, experiments as we know them are the kind of thing that happen at a particular place, across a particular interval of time. If theories like this are correct, we may need to rethink the very nature of experimentation so we can make sense of it in situations where space and time are absent.\n\nOn the other hand, the very fact we can perform straightforward experiments involving gravity at small scales may suggest that space and time are present after all.\n\nWhich will prove true? The best way to find out is to keep going with tabletop experiments, and to push them as far as they can go.",
    ]
    sentences_reference: list[str] = [sentence for content in content_reference for sentence in content.split("\n")]
    tokeniser_positive = NgramDictTokeniser(mwe_range, blacklist)
    tokeniser_negative = NgramDictTokeniser(mwe_range, blacklist)
    pipeline = StreamedPipeline()
    keyness_values = pipeline.extract_key_ngram_features(
        tokeniser_positive, 
        tokeniser_negative, 
        sentences_positive, 
        sentences_reference
        )    
